--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersInitialization by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.1.0 Compatible with Seasons
-- 30.11.2018 - 30.09.2019



RealNumbersInitialization = {};

-- Global print functions. Can be used in all scripts.

function myPrint(text, number, textWidth, unit)
	print(string.format("%s =  %8.0f %s", text..string.rep(" ",textWidth-string.len(text)),number,"    "..unit));
end;
function myPrintFloat(text, number, textWidth, unit)
	print(string.format("%s =  %12.4f %s", text..string.rep(" ",textWidth-string.len(text)),number, unit));
end;

function pairsByKeys (t, f)
	local a = {}
	for n in pairs(t) do table.insert(a, n) end
		table.sort(a, f)
		local i = 0      -- iterator variable
		local iter = function ()   -- iterator function
        i = i + 1
        if a[i] == nil then return nil
			else return a[i], t[a[i]]
        end
    end
    return iter
end

function round(x)
	local f = math.floor(x)
	if (x == f) or (x % 2.0 == 0.5) then
		return f;
	else
		return math.floor(x + 0.5);
	end
end

function print_r (t, indent, done)
  done = done or {}
  indent = indent or ''
  local nextIndent -- Storage for next indentation value
  for key, value in pairs (t) do
    if type (value) == "table" and not done [value] then
      nextIndent = nextIndent or
          (indent .. string.rep(' ',string.len(tostring (key))+2))
          -- Shortcut conditional allocation
      done [value] = true
      print (indent .. "[" .. tostring (key) .. "] => Table {");
      print  (nextIndent .. "{");
      print_r (value, nextIndent .. string.rep(' ',2), done)
      print  (nextIndent .. "}");
    else
      print  (indent .. "[" .. tostring (key) .. "] => " .. tostring (value).."")
    end
  end
end

function RealNumbersInitialization:loadMap(name)


	RN = {};										-- Global RealNumbers parameters
	RNS = {};										-- Global RealNumbers parameters for Seasons mod
	RN.isDebug                        = true;		-- if true: prints output to log file
	RN.hasNotRun					  = true;		-- prevens update from runing more than once
	RN.fieldWorkbaseYieldAdjustment   = 1/2;   		-- Scale down from desired yield to base yield (no lime and no ferilizer)
	RN.gameLevel                      = {};			-- Global game level correction factors
	RN.gameLevel.cropYieldCorrection  = 1;  		-- Crop yield is only 50% of specified if playing on economic level HARD
	RN.gameLevel.sellPriceMultiplier  = {3,1.8,1}; 	-- economic difficulty levels 1, 2, and 3
	RN.gameLevel.buyPriceMultiplier   = {0.4,0.7,1};-- economic difficulty levels 1, 2, and 3
	RN.DIRECT_SELL_MULTIPLIER         = 1.2000;		-- Presumably added sales price for selling used equipment at dealers shop
--	RN.DEFAULT_RUNNING_LEASING_FACTOR = 0.0021; 	-- Lease/hour as fraction of price. Ingame = 0.021.
--	RN.PER_DAY_LEASING_FACTOR         = 0.0010;		-- Lease/hour as fraction of price. Ingame default = 0.01
--	RN.DEFAULT_LEASING_DEPOSIT_FACTOR = 0.0020;		-- Lease deposit as fraction of price. Ingame default = 0.02
	RN.MAX_GREAT_DEMANDS              = 3.0000;		-- Found he parameter, is not used for anything yet.

	RN2 = {};

	RN.gameDaysPerYear 				  = 12;
	
	
-- leasing parameters

	RN.equipmentLifeYears = 6;						-- Life time of equipment in years
	RN.equipmentAnnualLoss = 0.15;					-- Anunual depreciation fctor
	RN.leaseInitialInstallment = 0.005;				-- Initial extra downpayment factor
	RN.leaseAnnualInterestRate = 0.05;				-- Lease annual interest rate


	local isDebug  = RN.isDebug;
	local isDebug2 = false;

	local modName = "FS19_RealLifeNumbers_US_Heartland";		-- GEO US Heartland,
	local RealLifeNumbersDirectory = g_modNameToDirectory[modName];
	RN.moddir = string.gsub(RealLifeNumbersDirectory, "/"..modName, "");
	if isDebug2 then print("RN moddir : "..tostring(RN.moddir)); end;

	RN.multiPlayer = g_currentMission.missionDynamicInfo.isMultiplayer;


-- contract rewards. Guessed numbers. Meassure your own missionHaPerHour and enter your personal work capacity.

	RN.runContractScript	 = true;	
	RN.missions              = {};
	RN.missionTypes          = { "mow_bale", "plow" , "cultivate", "sow", "harvest", "weed", "spray", "fertilize", "transport"};
	RN.farmServicePerHa      = {  300,        100,         35,      90,     150,       20,     25,        20,           0     };
	RN.missionHaPerHour      = {    1,          1,          3,       2,       1,        5,      5,         5,           0     };
	RN.vehicleUseCostPerHour = {   20,         10,         10,      10,      20,       10,     10,        10,           5     };
	RN.missionPayPerHour     = {   10,         10,         10,      10,      20,       20,     50,        10,          10     };
	RN.missionStart 		 = 10; 		-- contract start fee
	RN.transportStart        = 5;       -- transport start fee
	RN.objectFee             = 3.0;	    -- fee per object tranported
	RN.transportHour         = 1;		-- default duration of transport job is 1 hour

-- Helper salary can be set in Seasons

	RNS.pigs    = {};
	RNS.cows1    = {};
	RNS.cows2    = {};		-- Brahman breed
	RNS.sheep   = {};
	RNS.chicken = {};
	RNS.horses1  = {};
	RNS.horses2  = {};
	
-- FillType indices

--[[
	1 :: UNKNOWN, 2 :: WHEAT, 3 :: BARLEY, 4 :: OAT, 5 :: CANOLA, 6 :: SUNFLOWER, 7 :: SOYBEAN, 8 :: MAIZE
	9 :: POTATO, 10 :: SUGARBEET, 11 :: COTTON, 12 :: SUGARCANE, 13 :: SEEDS, 14 :: EGG, 15 :: WOOL, 16 :: MILK
	17 :: FUEL, 18 :: WATER, 19 :: FORAGE, 20 :: FORAGE_MIXING, 21 :: CHAFF, 22 :: TREESAPLINGS, 23 :: WOODCHIPS
	24 :: SILAGE, 25 :: OILSEEDRADISH, 26 :: POPLAR, 27 :: GRASS, 28 :: GRASS_WINDROW, 29 :: DRYGRASS,
	30 :: DRYGRASS_WINDROW, 31 :: STRAW, 32 :: DIESEL, 33 :: DEF, 34 :: AIR, 35 :: ROUNDBALE, 36 :: ROUNDBALE_GRASS
	37 :: ROUNDBALE_DRYGRASS, 38 :: ROUNDBALE_WHEAT, 39 :: ROUNDBALE_BARLEY, 40 :: SQUAREBALE, 41 :: SQUAREBALE_WHEAT
	42 :: SQUAREBALE_BARLEY, 43 :: FERTILIZER, 44 :: LIQUIDFERTILIZER, 45 :: MANURE, 46 :: LIQUIDMANURE
	47 :: DIGESTATE, 48 :: PIGFOOD, 49 :: TARP, 50 :: LIME, 51 :: HERBICIDE, 52 :: WEED, 53 :: HORSE_TYPE_BEIGE
	54 :: HORSE_TYPE_BLACK, 55 :: HORSE_TYPE_BROWN, 56 :: HORSE_TYPE_BROWN_WHITE, 57 :: HORSE_TYPE_DARK_BROWN
	58 :: HORSE_TYPE_GREY, 59 :: HORSE_TYPE_LIGHT_BROWN, 60 :: HORSE_TYPE_RED_BROWN, 61 :: COW_TYPE_BROWN
	62 :: COW_TYPE_BROWN_WHITE, 63 :: COW_TYPE_BLACK, 64 :: COW_TYPE_BLACK_WHITE, 65 :: COW_TYPE_BRAHMAN_BROWN
	66 :: COW_TYPE_BRAHMAN_WHITE, 67 :: COW_TYPE_BRAHMAN_LIGHT_BROWN, 68 :: COW_TYPE_BRAHMAN_GREY
	69 :: SHEEP_TYPE_WHITE, 70 :: SHEEP_TYPE_BROWN, 71 :: SHEEP_TYPE_BLACK_WHITE, 72 :: SHEEP_TYPE_BLACK
	73 :: PIG_TYPE_RED, 74 :: PIG_TYPE_WHITE, 75 :: PIG_TYPE_BLACK_WHITE, 76 :: PIG_TYPE_BLACK
	77 :: CHICKEN_TYPE_BLACK, 78 :: CHICKEN_TYPE_WHITE, 79 :: CHICKEN_TYPE_BROWN, 80 :: CHICKEN_TYPE_ROOSTER
--]]
-- FruitType indices

	-- WHEAT :: 1, BARLEY :: 2, OAT :: 3, COTTON :: 4, CANOLA :: 5, SUNFLOWER :: 6,
	-- SOYBEAN :: 7, MAIZE :: 8, POTATO :: 9, SUGARBEET :: 10, OILSEEDRADISH :: 11,
	-- POPLAR :: 12, GRASS :: 13, DRYGRASS :: 14, SUGARCANE :: 15, WEED :: 16

-- Hereunder are all major parameter values in FS19_RealLifeNumbers.
-- Each value can be changed. But the structure and order must remain unchanged. Additional numbers cannot be appended.

-- Spraying

	RN.sprayNames =              {  "FERTILIZER", "LIQUIDFERTILIZER", "MANURE", "LIQUIDMANURE", "DIGESTATE", "LIME", "HERBICIDE"}
	RN.sprayTypeDensity =        {       0.8,            1.3,           0.6,        0.9,            0.9,       1.2,      1.0    };		-- kg/liter
	RN.sprayCalibrationFactor =  {     1.000,          1.000,         1.000,      1.000,          1.000,     0.778,    1.000    };
	RN.Nweight	=						0.1;	-- weight for meeting nitrogen requirement
	RN.Pweight =                        0.8;	-- weight for meeting phosphate requirement
	RN.Kweight =                        0.1;	-- weight for meeting potassium requirement

	RN.soilType =                       2;		-- 1: Sands and loamy sands: 2: Sandy loams and silt loam; 3: Clay loams and clay
	RN.soilCurrentpH =                  6;		-- determinant for lime application rate
	RN.soilTargetpH =                 6.7;		-- determinant for lime application rate
	RN.limeNV =                        50;		-- "Neutralizing Value", concentration of calcium in lime material, 0 - 100, Ground limestone = 50
	RN.HerbicideKgPerHa =               2;

	RN.pigSlurryFraction =            0.5;		-- fraction of Farm slurry originating from pigs. The rest is cow slurry.
	RN.pigManureFraction =            0.5;		-- fraction of manure spread on fields originating from pigs
	RN.organicFertilizerFraction =    0.3;		-- fraction of fertilizer spread on fields originating from organic sources
	RN.numberOfFertilizings			=   3;		-- Number of fertilizer applications per year
	RN.liqfertDilutionFactor =         1;		-- 1 Liter of liquid fertilizer is diluted to x liter of solution
	RN.liqfertLiquidReductionFactor =   2;		-- liquid fertilizer is needed in smaller dosis due to better uptake
	RN.herbicideDilutionFactor =      200;		-- 1 liter of herbicide to 200 liter of water
	RN.annualGrassCuttings			=   2;

	RN.kgNPerTonneCompost			=   9.0;	-- kg nitrogen per Tonne compost, 3 - 15 kg/T
	RN.kgPPerTonneCompost			=   5.5;	-- kg posphate per Tonne compost, 1 - 10 kg/T
	RN.kgKPerTonneCompost			=   6.5;	-- kg potassium per Tonne compost, 3 - 10 kg/T

-- Field prices

	RN.annualLoanInterest =      4;				-- Annual interest rate on loans
	RN.loanMax =           3000000;				-- Max loan
	RN.pricePerHa =         11532; 				-- GEO US Heartland, purchase price of farmland per hectare
	RN.rentPricePerHa = 0.033 * RN.pricePerHa;	-- rent price of farmland per hectare
	RN.gameDayOfYearRentTerminates	= 1;		-- Game day of the year when field rent contracts terminate

	RN.rentedFields =            { 5, 9, 14, 16, 20, 23, 28, 32, 38, 43, 49, 56, 60, 67, 73, 84}; -- Numbers for fields to be rentable

	RN.treeSaplingsUnitPrice = 1.0;
	

-- Animal products

	RN.animalProduct =              {"MILK", "WOOL",  "EGG"};
    RN.animalProductDensity =       {1.025,   0.375,   1.2 };	-- kg/L 6 eggs x 0.06 kg in 1.4 L (16x11x8 cm)
	RN.animalProductPricePer100kg = {43.78,  152.78, 157.43 };	-- GEO US Heartland price per 100 kg

-- Animal care

	RNS.pigs.color               = {     "RED",         "WHITE",          "BLACK_WHITE",         "BLACK"     };
	RNS.pigs.type                = { "Yorkshire","Gloucestershire Old Spot","Spotted",         "Berkshire"   };
	RNS.pigs.fillType            = {      73,              74,                 75,                  76       };
	RNS.pigs.strawPerDay 		 = {      1,                2,                  1,                   2       }; -- kg/day
	RNS.pigs.waterPerDayPerKg    = {    0.03,            0.03,               0.03,                0.03       }; -- L/day/kg BW
	RNS.pigs.foodPerDayPerKg     = {    0.03,            0.03,               0.03,                0.03       }; -- kg wet matter/day/kg BW
	RNS.pigs.buyWeight           = {   190.0,              24,                145,                26.0       }; -- kg
	RNS.pigs.bornWeight          = {   1.575,           1.125,               1.35,               1.575       }; -- kg
	RNS.pigs.milkPerDay          = {    0.00,            0.00,               0.00,                0.00       }; -- L/day
	RNS.pigs.manurePerDayPerKg   = {   0.065,           0.065,              0.065,               0.065       }; -- kg/day/kg BW
	RNS.pigs.liquidManure        = {   0.039,           0.039,              0.039,               0.039       }; -- kg/day/kg BW
	RNS.pigs.foodSpillage        = {    0.00,            0.00,               0.00,                0.00       }; -- L/day or perhaps percentage default 0.06
	RNS.pigs.fertileAge          = {     0.4,               0,                0.4,                   0       }; -- year
	RNS.pigs.averageLitterSize   = {     9.1,               0,                7.5,                   0       }; -- number
	RNS.pigs.variationLitterSize = {       5,               0,                  5,                   0       }; -- number
	RNS.pigs.birthRate           = {       8,               0,                  8,                   0       }; 
	RNS.pigs.femalePercentage    = {     0.9,               0,                0.9,                   0       };
	RNS.pigs.dailyUpkeep         = {       0,               0,                  0,                   0       }; -- €
	RNS.pigs.buyPriceMultiplier  = {     1.2,             1.2,                1.2,                 1.2       };
	RNS.pigs.baseSellPrice       = {     100,             100,                100,                 100       }; -- €
	RNS.pigs.pricePerKg          = {    0.77,            0.77,               0.77,                0.77       }; -- GEO US Heartland €/kg live weight
	RNS.pigs.priceDropAge        = {     180,             180,                180,                 180       }; -- days
	RNS.pigs.transportPrice      = {      10,              10,                 10,                  10       }; -- €
	RNS.pigs.buyAge              = {     365,              56,                365,                  56       }; -- year
	RNS.pigs.buyIsFemale         = {    true,           false,               true,               false       };

	RNS.cows1.color              = {   "BROWN",       "BROWN_WHITE",         "BLACK",       "BLACK_WHITE"    };
	RNS.cows1.type               = {  "Limousin",       "Ayrshire",          "Saler",         "Holstein"     };
	RNS.cows1.fillType           = {      61,              62,                 63,                  64       };
	RNS.cows1.strawPerDay 		 = {     1.4,             1.4,                1.4,                 1.4       }; -- kg/day
	RNS.cows1.waterPerDayPerKg   = {    0.09,            0.17,               0.09,                0.17       }; -- kg/day/kg BW
	RNS.cows1.foodPerDayPerKg    = {   0.069,           0.069,              0.069,               0.069       }; -- kg wet matter/day/kg BW
	RNS.cows1.foodTroughFraction = {    0.05,             0.1,               0.05,                 0.1       }; -- fraction of cow feed eaten in feed trough
	RNS.cows1.buyWeight          = {     280,             410,                275,                 490       };
	RNS.cows1.bornWeight         = {   40.05,           32.40,              38.00,               40.50       };
	RNS.cows1.milkPerDay         = {    0.00,           25.00,               0.00,               29.00       };
	RNS.cows1.manurePerDayPerKg  = {   0.082,           0.082,              0.082,               0.082       }; -- kg/day/kg BW
	RNS.cows1.liquidManure       = {   0.080,           0.130,              0.080,               0.130       }; -- kg/day/kg BW
	RNS.cows1.foodSpillage       = {    0.00,            0.00,               0.00,                0.00       };	-- default 0.05
	RNS.cows1.fertileAge         = {       0,               2,                  0,                1.25       };
	RNS.cows1.averageLitterSize  = {       0,               1,                  0,                   1       };
	RNS.cows1.variationLitterSize= {       0,               0,                  0,                   0       };
	RNS.cows1.birthRate          = {       0,               4,                  0,                   4       };
	RNS.cows1.femalePercentage   = {       0,             0.9,                  0,                 0.9       };
	RNS.cows1.dailyUpkeep        = {       0,               0,                  0,                   0       };
	RNS.cows1.buyPriceMultiplier = {     1.2,             1.2,                1.2,                 1.2       };
	RNS.cows1.baseSellPrice      = {     500,             250,                300,                 400       };
	RNS.cows1.pricePerKg         = {    1.07,            1.07,               1.07,                1.07       }; -- GEO US Heartland €/kg live weight
	RNS.cows1.priceDropAge       = {    1100,            1100,               1100,                1100       };
	RNS.cows1.transportPrice     = {      20,              20,                 20,                  20       };
	RNS.cows1.buyAge             = {     230,             700,                300,                 700       };
	RNS.cows1.buyIsFemale        = {   false,            true,              false,                true       };
	
	RNS.cows2.color              = {"BRAHMAN_BROWN", "BRAHMAN_WHITE", "BRAHMAN_LIGHT_BROWN","BRAHMAN_GREY"   };
	RNS.cows2.type               = {"Brahman (brown)","Brahman (white)","Brahman (light brown)","Brahman (grey)"};
	RNS.cows2.fillType           = {      65,              66,                 67,                  68       };
	RNS.cows2.strawPerDay 		 = {     1.4,             1.4,                1.4,                 1.4       };
	RNS.cows2.waterPerDayPerKg   = {    0.09,            0.09,               0.09,                0.09       }; -- kg/day/kg BW
	RNS.cows2.foodPerDayPerKg    = {   0.050,           0.050,              0.050,               0.050       }; -- kg wet matter/day/kg BW
	RNS.cows2.foodTroughFraction = {    0.05,            0.05,               0.05,                0.05       }; -- fraction of cow feed eaten in feed trough
	RNS.cows2.buyWeight          = {     260,             260,                260,                 260       };
	RNS.cows2.bornWeight         = {   29.25,           29.25,              29.25,               29.25       };
	RNS.cows2.milkPerDay         = {    0.00,            0.00,               0.00,                0.00       };
	RNS.cows2.manurePerDayPerKg  = {   0.062,           0.062,              0.062,               0.062       }; -- kg/day/kg BW
	RNS.cows2.liquidManure       = {   0.070,           0.070,              0.070,               0.070       }; -- kg/day/kg BW
	RNS.cows2.foodSpillage       = {    0.00,            0.00,               0.00,                0.00       };	-- dfault 0.05
	RNS.cows2.fertileAge         = {       0,               0,                  0,                   0       };
	RNS.cows2.averageLitterSize  = {       0,               0,                  0,                   0       };
	RNS.cows2.variationLitterSize= {       0,               0,                  0,                   0       };
	RNS.cows2.birthRate          = {       0,               0,                  0,                   0       };
	RNS.cows2.femalePercentage   = {       0,               0,                  0,                   0       };
	RNS.cows2.dailyUpkeep        = {       0,               0,                  0,                   0       };
	RNS.cows2.buyPriceMultiplier = {     1.2,             1.2,                1.2,                 1.2       };
	RNS.cows2.baseSellPrice      = {     300,             300,                300,                 300       };
	RNS.cows2.pricePerKg         = {    1.07,            1.07,               1.07,                1.07       }; -- GEO US Heartland €/kg live weight
	RNS.cows2.priceDropAge       = {    1100,            1100,               1100,                1100       };
	RNS.cows2.transportPrice     = {      20,              20,                 20,                  20       };
	RNS.cows2.buyAge             = {     300,             300,                300,                 300       };
	RNS.cows2.buyIsFemale        = {   false,           false,              false,               false       };
	
	RNS.sheep.color               = {   "WHITE",         "BROWN",          "BLACK_WHITE",          "BLACK"    };
	RNS.sheep.type                = {  "Dorset",         "Merino",           "Suffolk",            "Dorper"   };
	RNS.sheep.fillType            = {      69,              70,                 71,                  72       };
	RNS.sheep.strawPerDay 		  = {     0.0,             0.0,                0.0,                 0.0       };
	RNS.sheep.waterPerDayPerKg    = {    0.04,            0.04,               0.04,                0.04       }; -- kg/day/kg BW
	RNS.sheep.foodPerDayPerKg     = {   0.085,           0.085,              0.085,               0.085       }; -- kg wet matter/day/kg BW
	RNS.sheep.foodTroughFraction  = {     0.1,             0.1,                0.1,                 0.1       }; -- fraction of cow feed eaten in feed trough
	RNS.sheep.buyWeight           = {    65.0,              50,                 70,                  60       };
	RNS.sheep.bornWeight          = {    4.77,            5.45,              6.255,               5.445       };
	RNS.sheep.milkPerDay          = {    0.00,            0.00,               0.00,                0.00       };
	RNS.sheep.manurePerDayPerKg   = {    0.00,            0.00,               0.00,                0.00       };
	RNS.sheep.liquidManure        = {    0.00,            0.00,               0.00,                0.00       };
	RNS.sheep.foodSpillage        = {    0.00,            0.00,               0.00,                0.00       }; -- default 0.04
	RNS.sheep.woolKgPerYear       = {    8.20,            8.20,               8.20,                   0       }; -- kg wool per animal per year
	RNS.sheep.fertileAge          = {     0.6,             0.6,                0.6,                 0.6       };
	RNS.sheep.averageLitterSize   = {    1.55,            1.23,               1.65,                 1.8       };
	RNS.sheep.variationLitterSize = {       1,               1,                  1,                   1       };
	RNS.sheep.birthRate           = {       6,               6,                  6,                   6       };
	RNS.sheep.femalePercentage    = {     0.5,             0.5,                0.5,                 0.5       };
	RNS.sheep.dailyUpkeep         = {       0,               0,                  0,                   0       };
	RNS.sheep.buyPriceMultiplier  = {     1.2,             1.2,                1.2,                 1.2       };
	RNS.sheep.baseSellPrice       = {     300,             300,                300,                 300       };
	RNS.sheep.pricePerKg          = {    0.80,            0.80,               0.80,                0.80       }; -- GEO US Heartland €/kg live weight
	RNS.sheep.priceDropAge        = {     100,             100,                100,                 100       };
	RNS.sheep.transportPrice      = {      10,              10,                 10,                  10       };
	RNS.sheep.buyAge              = {     365,             365,                365,                 365       };
	RNS.sheep.buyIsFemale         = {    true,            true,               true,                true       };

	RNS.chicken.color            = {   "BLACK",          "WHITE",            "BROWN",           "ROOSTER"    };
	RNS.chicken.type             = {  "Cornish Cross", "White Leghorn",  "Rhode Island Red",    "Rooster"    };
	RNS.chicken.fillType         = {      77,              78,                 79,                  80       };
	RNS.chicken.strawPerDay 	 = {     0.0,             0.0,                0.0,                 0.0       };
	RNS.chicken.waterPerDayPerKg = {     0.1,             0.1,                0.1,                 0.1       }; -- kg/day/kg BW
	RNS.chicken.foodPerDayPerKg  = {  0.0545,          0.0545,             0.0545,                 0.0545    }; -- kg/day/kg BW
	RNS.chicken.buyWeight        = {    0.18,           2.138,              2.655,                 6.0       };
	RNS.chicken.bornWeight       = {   0.036,           0.020,              0.020,                   0       };
	RNS.chicken.milkPerDay       = {    0.00,            0.00,               0.00,                0.00       };
	RNS.chicken.manurePerDayPerKg= {   0.030,           0.030,              0.030,               0.030       }; -- kg/day/kg BW
	RNS.chicken.liquidManure     = {    0.00,            0.00,               0.00,                0.00       }; -- kg/day/kg BW
	RNS.chicken.foodSpillage     = {    0.00,            0.00,               0.00,                0.00       }; -- default 0.02
	RNS.chicken.eggsPerYear      = {       0,             275,                275,                   0       }; -- eggs per hen per year
	RNS.chicken.fertileAge       = {       0,             0.4,                0.4,                   0       };
	RNS.chicken.averageLitterSize= {       0,               1,                  1,                   0       };
	RNS.chicken.variationLitterSize= {     0,               0,                  0,                   0       };
	RNS.chicken.birthRate        = {       0,              10,                 10,                   6       };
	RNS.chicken.femalePercentage = {       0,             0.5,                0.5,                   0       };
	RNS.chicken.dailyUpkeep      = {       0,               0,                  0,                   0       };
	RNS.chicken.buyPriceMultiplier  = {  1.2,             1.2,                1.2,                 1.2       };
	RNS.chicken.baseSellPrice    = {     0.5,             0.5,                0.5,                 0.5       };
	RNS.chicken.pricePerKg       = {    0.88,            0.88,               0.88,                0.88       }; -- GEO US Heartland $/kg live weight
	RNS.chicken.priceDropAge     = {      30,              30,                 30,                  30       };
	RNS.chicken.transportPrice   = {       0,               0,                  0,                   0       };
	RNS.chicken.buyAge           = {       7,             140,                140,                 200       };
	RNS.chicken.buyIsFemale      = {   false,            true,               true,               false       };

	RNS.horses1.color            = {"HORSE_TYPE_GREY","HORSE_TYPE_BROWN_WHITE","HORSE_TYPE_BEIGE","HORSE_TYPE_RED_BROWN"    };
	RNS.horses1.type             = {  "Andalusian",     "Paint",           "Haflinger",    "Quarter Horse"   };
	RNS.horses1.fillType         = {      58,              56,                 53,                  60       };
	RNS.horses1.strawPerDay 	 = {       5,               5,                  5,                   5       }; -- kg/day
	RNS.horses1.waterPerDayPerKg = {   0.084,           0.084,              0.084,               0.084       }; -- kg/day/kg BW
	RNS.horses1.foodPerDayPerKg  = {   0.025,           0.025,              0.025,               0.025       }; -- kg/day/kg BW
	RNS.horses1.buyWeight        = {     545,             470,                430,                 455       };
	RNS.horses1.bornWeight       = {       0,               0,                  0,                   0       };
	RNS.horses1.milkPerDay       = {    0.00,            0.00,               0.00,                0.00       };
	RNS.horses1.manurePerDayPerKg= {    0.04,            0.04,               0.04,                0.04       }; -- kg/day/kg BW
	RNS.horses1.liquidManure     = {   0.021,           0.021,              0.021,               0.021       }; -- kg/day/kg BW
	RNS.horses1.foodSpillage     = {    0.00,            0.00,               0.00,                0.00       };
	RNS.horses1.dailyUpkeep      = {       0,               0,                  0,                   0       };
	RNS.horses1.buyPriceMultiplier = {     0,               0,                  0,                   0       };
	RNS.horses1.baseSellPrice    = {       0,               0,                  0,                   0       };
	RNS.horses1.pricePerKg       = {       0,               0,                  0,                   0       };
	RNS.horses1.priceDropAge     = {       0,               0,                  0,                   0       };
	RNS.horses1.transportPrice   = {      50,              50,                 50,                  50       };
	RNS.horses1.buyAge           = {    1000,            1000,               1000,                1000       };
	RNS.horses1.buyIsFemale      = {   false,           false,              false,               false       };
	RNS.horses1.cleanDuration    = {    5000,            5000,               5000,                5000       };
	RNS.horses1.liveryIncome     = {    5600,            4300,               5000,                4600       };
	RNS.horses1.trainingDifficulty= {    1.5,             1.1,                1.3,                 1.2       };

	RNS.horses2.color            = {"HORSE_TYPE_BROWN","HORSE_TYPE_BLACK","HORSE_TYPE_DARK_BROWN","HORSE_TYPE_LIGHT_BROWN"    };
	RNS.horses2.type             = {  "Thoroughbred", "Black Arabian","Tennessee Walking Horse","Morgan"     };
	RNS.horses2.fillType         = {      55,              54,                 57,                  59       };
	RNS.horses2.strawPerDay 	 = {       5,               5,                  5,                   5       }; -- kg/day
	RNS.horses2.waterPerDayPerKg = {   0.084,           0.084,              0.084,               0.084       }; -- kg/day/kg BW
	RNS.horses2.foodPerDayPerKg  = {   0.025,           0.025,              0.025,               0.025       }; -- kg/day/kg BW
	RNS.horses2.buyWeight        = {     450,             410,                415,                 420       };
	RNS.horses2.bornWeight       = {       0,               0,                  0,                   0       };
	RNS.horses2.milkPerDay       = {    0.00,            0.00,               0.00,                0.00       };
	RNS.horses2.manurePerDayPerKg= {    0.04,            0.04,               0.04,                0.04       }; -- kg/day/kg BW
	RNS.horses2.liquidManure     = {   0.021,           0.021,              0.021,               0.021       }; -- kg/day/kg BW
	RNS.horses2.foodSpillage     = {    0.00,            0.00,               0.00,                0.00       };
	RNS.horses2.dailyUpkeep      = {       0,               0,                  0,                   0       };
	RNS.horses2.buyPriceMultiplier = {     0,               0,                  0,                   0       };
	RNS.horses2.baseSellPrice    = {       0,               0,                  0,                   0       };
	RNS.horses2.pricePerKg       = {       0,               0,                  0,                   0       };
	RNS.horses2.priceDropAge     = {       0,               0,                  0,                   0       };
	RNS.horses2.transportPrice   = {      50,              50,                 50,                  50       };
	RNS.horses2.buyAge           = {    1000,            1000,               1000,                1000       };
	RNS.horses2.buyIsFemale      = {   false,           false,              false,               false       };
	RNS.horses2.cleanDuration    = {    5000,            5000,               5000,                5000       };
	RNS.horses2.liveryIncome     = {    6000,            7000,               5300,                4000       };
	RNS.horses2.trainingDifficulty= {    1.6,             1.8,                1.4,                 1.0       };


-- Fruit Types

	RN.fruits = {};
	RN.cropDensity = {};
	RN.cropYield = {};
	RN.yieldRange = {};
	RN.cropBonusYieldLitersPerHa = {};
	RN.cropPricePer100kg = {};
	RN.cropPricePerHa = {};
	RN.cropPricePerLiter = {};
	RN.windrowYieldLitersPerHa = {};
	RN.windrowYieldkgPerHa = {};
	RN.seedDensity = {};
	RN.TSM = {};
	RN.plantsPerSqm = {};
	RN.germination = {};
	RN.growthDays = {};
	RN.minGrowthState = {};
	RN.maxGrowthState = {};
	RN.seedUsagePerSqm = {};
	RN.seedMassRatePerHa = {};
	RN.seedVolumeRatePerHa = {};
	RN.seedPricePer100kg = {};
	RN.seedCostPerHa = {};
	RN.seedCostPerLiter = {};
	RN.seederCalibration = {};
	RN.rowSpacing  = {};
	RN.plantSpacing  = {};
	
	RN.bonusYieldPerHa = {};
	RN.Nitrogen = {};
	RN.Phosphate = {};
	RN.Potassium = {};

	RN.pricePerLiter = {};			-- price
	RN.massPerLiter = {}; 			-- density
	RN.literPerSqm = {};			-- yield
	RN.windrowLiterPerSqm = {};		-- windrow yield
	RN.strawYieldFactor = 0.80;		-- Mass of straw divided by mass of grain

	RN.rowSpacing.POPLAR = 3;  		-- meters between rows, 3 - 5 meters
	RN.plantSpacing.POPLAR = 2;		-- meters between plants in a row, 2 - 4 meters
	RN.plantsPerSqm.POPLAR = 1/(RN.rowSpacing.POPLAR * RN.plantSpacing.POPLAR);

	RN.Nitrogen.UNDEFINED					= 126;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.UNDEFINED					= 46;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.UNDEFINED					= 112;		-- kg/ha Potassium (K) fertilizer per year

	RN.fruits.ALFALFA 						= "ALFALFA";-- Lucerne
	RN.cropDensity.ALFALFA 					= 0.46;		-- kg/L
	RN.cropYield.ALFALFA  					= 198.12; 	-- GEO EU, 100 kg/ha
	RN.yieldRange.ALFALFA  					= 0.177		-- GEO EU,
	RN.seedDensity.ALFALFA  				= 0.737;	-- kg/L
	RN.TSM.ALFALFA  						= 2;		-- 1000 seed mass
	RN.plantsPerSqm.ALFALFA  				= 360;		-- number of plants per sqm
	RN.germination.ALFALFA  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.ALFALFA 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.ALFALFA  			= 46.00;	-- GEO UK, price / 100 kg
	RN.cropPricePer100kg.ALFALFA  			= 17.80;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.ALFALFA  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.ALFALFA						= 40;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.ALFALFA					= 80 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.ALFALFA					= 120;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.ALFALFA					= 60;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.ASPARAGUS  					= "ASPARAGUS";	
	RN.cropDensity.ASPARAGUS 				= 0.325;	-- kg/L
	RN.cropYield.ASPARAGUS  				= 54.37; 	-- GEO DE, 100 kg/ha
	RN.yieldRange.ASPARAGUS  				= 0.179;	-- GEO DE
	RN.seedDensity.ASPARAGUS  				= 0.288;	-- kg/L
	RN.TSM.ASPARAGUS  						= 257;		-- 1000 seed mass
	RN.plantsPerSqm.ASPARAGUS  				= 40;		-- number of plants per sqm
	RN.germination.ASPARAGUS  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.ASPARAGUS 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.ASPARAGUS  		= 46.00;	-- GEO COM price / 100 kg
	RN.cropPricePer100kg.ASPARAGUS  		= 419.50;	-- GEO DE price / 100 kg
	RN.seederCalibration.ASPARAGUS  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.ASPARAGUS					= 100;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.ASPARAGUS					= 11 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.ASPARAGUS					= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.ASPARAGUS					= 60;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.BARLEY  						= "BARLEY";
	RN.cropDensity.BARLEY 					= 0.618;	-- kg/L
	RN.cropYield.BARLEY  					= 36.94; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.BARLEY  					= 0.201;	-- GEO US Heartland,
	RN.seedDensity.BARLEY  					= 0.618;	-- kg/L
	RN.TSM.BARLEY  							= 40;		-- 1000 seed mass
	RN.plantsPerSqm.BARLEY  				= 210;		-- number of plants per sqm
	RN.germination.BARLEY  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.BARLEY 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.BARLEY  			= 55.00;	-- GEO US Heartland, price / 100 kg
	RN.cropPricePer100kg.BARLEY  			= 18.61;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.BARLEY  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.BARLEY						= 174;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.BARLEY						= 74 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.BARLEY						= 176;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.BARLEY					= 100;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.BEAN  						= "BEAN";	-- Green beans
	RN.cropDensity.BEAN 					= 0.288;	-- kg/L
	RN.cropYield.BEAN  						= 23.90; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.BEAN  					= 0.394;	-- GEO COM,
	RN.seedDensity.BEAN  					= 0.288;	-- kg/L
	RN.TSM.BEAN  							= 257;		-- 1000 seed mass
	RN.plantsPerSqm.BEAN  					= 40;		-- number of plants per sqm
	RN.germination.BEAN  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.BEAN 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.BEAN  				= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.BEAN  				= 44.60;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.BEAN  				= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.BEAN						= 100;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.BEAN						= 11 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.BEAN						= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.BEAN						= 100;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.BEANS  						= "BEANS";	-- Green beans
	RN.cropDensity.BEANS 					= 0.288;	-- kg/L
	RN.cropYield.BEANS  					= 23.90; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.BEANS  					= 0.394;	-- GEO COM,
	RN.seedDensity.BEANS  					= 0.288;	-- kg/L
	RN.TSM.BEANS  							= 257;		-- 1000 seed mass
	RN.plantsPerSqm.BEANS  					= 40;		-- number of plants per sqm
	RN.germination.BEANS  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.BEANS 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.BEANS  			= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.BEANS  			= 44.60;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.BEANS  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.BEANS						= 100;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.BEANS						= 11 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.BEANS						= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.BEANS						= 100;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.BLACKBEANS  					= "BLACKBEANS";
	RN.cropDensity.BLACKBEANS 				= 0.288;	-- kg/L
	RN.cropYield.BLACKBEANS  				= 23.90; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.BLACKBEANS  				= 0.394;	-- GEO COM,
	RN.seedDensity.BLACKBEANS  				= 0.288;	-- kg/L
	RN.TSM.BLACKBEANS  						= 257;		-- 1000 seed mass
	RN.plantsPerSqm.BLACKBEANS  			= 40;		-- number of plants per sqm
	RN.germination.BLACKBEANS  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.BLACKBEANS 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.BLACKBEANS  		= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.BLACKBEANS  		= 44.60;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.BLACKBEANS  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.BLACKBEANS					= 100;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.BLACKBEANS					= 11 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.BLACKBEANS					= 70;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.BLACKBEANS				= 100;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.CABBAGE  						= "CABBAGE";-- Savoy
	RN.cropDensity.CABBAGE 					= 0.433;	-- kg/L
	RN.cropYield.CABBAGE  					= 429.7; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.CABBAGE  					= 0.198;	-- GEO COM,
	RN.seedDensity.CABBAGE  				= 0.433;	-- kg/L
	RN.TSM.CABBAGE  						= 3.3;		-- 1000 seed mass
	RN.plantsPerSqm.CABBAGE  				= 20;		-- number of plants per sqm
	RN.germination.CABBAGE  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.CABBAGE 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.CABBAGE  			= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.CABBAGE  			= 39.77;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.CABBAGE  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.CABBAGE						= 90;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.CABBAGE					= 90;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.CABBAGE					= 90;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.CABBAGE					= 90;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.CANOLA  						= "CANOLA";
	RN.cropDensity.CANOLA 					= 0.644;	-- kg/L
	RN.cropYield.CANOLA  					= 17.00; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.CANOLA  					= 0.317;	-- GEO US Heartland,
	RN.seedDensity.CANOLA  					= 0.644;	-- kg/L
	RN.TSM.CANOLA  							= 2.5;		-- 1000 seed mass
	RN.plantsPerSqm.CANOLA  				= 100;		-- number of plants per sqm
	RN.germination.CANOLA  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.CANOLA 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.CANOLA  			= 36.00;	-- GEO US Heartland, price / 100 kg
	RN.cropPricePer100kg.CANOLA  			= 36.71;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.CANOLA  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.CANOLA						= 134;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.CANOLA						= 49;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.CANOLA						= 41;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.CANOLA					= 90;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.CARROT  						= "CARROT";
	RN.cropDensity.CARROT 					= 0.641;	-- kg/L
	RN.cropYield.CARROT  					= 483.46; 	-- GEO US, 100 kg/ha
	RN.yieldRange.CARROT  					= 0.198;	-- GEO COM,
	RN.seedDensity.CARROT  					= 0.400;	-- kg/L
	RN.TSM.CARROT  							= 1.3;		-- 1000 seed mass
	RN.plantsPerSqm.CARROT  				= 170;		-- number of plants per sqm
	RN.germination.CARROT  					= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.CARROT 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.CARROT  			= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.CARROT  			= 26.44;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.CARROT  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.CARROT						= 240;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.CARROT						= 82 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.CARROT						= 143;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.CARROT					= 75;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.CLOVER  						= "CLOVER";
	RN.cropDensity.CLOVER 					= 0.46;		-- kg/L
	RN.cropYield.CLOVER  					= 165.8; 	-- 100 kg/ha, set to grass
	RN.yieldRange.CLOVER  					= 0.153;	-- GEO COM,
	RN.seedDensity.CLOVER  					= 0.641;	-- kg/L
	RN.TSM.CLOVER  							= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.CLOVER  				= 550;		-- number of plants per sqm
	RN.germination.CLOVER  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.CLOVER 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.CLOVER  			= 350.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.CLOVER  			= 10;		-- GEO Com, price / 100 kg, set to 2 x grass
	RN.seederCalibration.CLOVER  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.CLOVER						= 27;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.CLOVER						= 9;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.CLOVER						= 44;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.CLOVER					= 60;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.COFFEE   						= "COFFEE";
	RN.cropDensity.COFFEE 					= 0.513;	-- kg/L
	RN.cropYield.COFFEE  					= 11.43; 	-- GEO US Average,100 kg/ha
	RN.yieldRange.COFFEE  					= 0.27;		-- GEO COM,
	RN.seedDensity.COFFEE  					= 0.412;	-- kg/L
	RN.TSM.COFFEE  							= 0;		-- 1000 seed mass
	RN.plantsPerSqm.COFFEE  				= 0;		-- number of plants per sqm
	RN.germination.COFFEE  					= 1;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.COFFEE 				= 0.05;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.COFFEE  			= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.COFFEE  			= 2068;		-- GEO US Average, price / 100 kg
	RN.seederCalibration.COFFEE  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.COFFEE						= 250;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.COFFEE						= 40;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.COFFEE						= 325;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.COFFEE					= 90;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.COTTON  						= "COTTON";	-- Cotton fibre
	RN.cropDensity.COTTON 					= 0.23;		-- kg/L
	RN.cropYield.COTTON  					= 12.70; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.COTTON  					= 0.200;	-- GEO COM
	RN.seedDensity.COTTON  					= 0.412;	-- kg/L
	RN.TSM.COTTON  							= 236.8;	-- 1000 seed mass
	RN.plantsPerSqm.COTTON  				= 9.5;		-- number of plants per sqm
	RN.germination.COTTON  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.COTTON 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.COTTON  			= 17.00;	-- GEO US Heartland, price / 100 kg
	RN.cropPricePer100kg.COTTON  			= 160.7;	-- GEO US Average 2018, price / 100 kg
	RN.seederCalibration.COTTON  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.COTTON						= 80;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.COTTON						= 40;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.COTTON						= 40;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.COTTON					= 158;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.CRANBERRY   					= "CRANBERRY";
	RN.cropDensity.CRANBERRY 				= 0.641;	-- kg/L
	RN.cropYield.CRANBERRY  				= 363.6; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.CRANBERRY  				= 0.15;		-- GEO COM,
	RN.seedDensity.CRANBERRY  				= 0.412;	-- kg/L
	RN.TSM.CRANBERRY  						= 10.71;	-- 1000 seed mass
	RN.plantsPerSqm.CRANBERRY  				= 21;		-- number of plants per sqm
	RN.germination.CRANBERRY  				= 1;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.CRANBERRY 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.CRANBERRY  		= 60.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.CRANBERRY  		= 40.60;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.CRANBERRY  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.CRANBERRY					= 80;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.CRANBERRY					= 45;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.CRANBERRY					= 10;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.CRANBERRY					= 60;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.DRYGRASS  					= "DRYGRASS";
	RN.cropDensity.DRYGRASS 				= 0.18;		-- kg/L
	RN.cropYield.DRYGRASS  					= 54.50; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.DRYGRASS  				= 0.153;	-- GEO COM,
	RN.seedDensity.DRYGRASS  				= 0.641;	-- kg/L
	RN.TSM.DRYGRASS  						= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.DRYGRASS  				= 550;		-- number of plants per sqm
	RN.germination.DRYGRASS  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.DRYGRASS 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.DRYGRASS  			= 350.00;	-- GEO UK, price / 100 kg
	RN.cropPricePer100kg.DRYGRASS  			= 11.70;	-- GEO UK, price / 100 kg
	RN.seederCalibration.DRYGRASS  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.DRYGRASS					= 0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.DRYGRASS					= 0;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.DRYGRASS					= 0;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.DRYGRASS					= 60;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.SEMIDRY_GRASS_WINDROW  			= "SEMIDRY_GRASS_WINDROW";
	RN.cropDensity.SEMIDRY_GRASS_WINDROW 		= 0.18;		-- kg/L
	RN.cropYield.SEMIDRY_GRASS_WINDROW  		= 76.55; 	-- GEO DE,100 kg/ha
	RN.yieldRange.SEMIDRY_GRASS_WINDROW  		= 0.153;	-- GEO DE
	RN.seedDensity.SEMIDRY_GRASS_WINDROW  		= 0.641;	-- kg/L
	RN.TSM.SEMIDRY_GRASS_WINDROW  				= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.SEMIDRY_GRASS_WINDROW  		= 550;		-- number of plants per sqm
	RN.germination.SEMIDRY_GRASS_WINDROW  		= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SEMIDRY_GRASS_WINDROW 	= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SEMIDRY_GRASS_WINDROW  = 350.00;	-- GEO DE, price / 100 kg
	RN.cropPricePer100kg.SEMIDRY_GRASS_WINDROW  = 11.70;	-- GEO DE, price / 100 kg
	RN.seederCalibration.SEMIDRY_GRASS_WINDROW  = 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SEMIDRY_GRASS_WINDROW			= 0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SEMIDRY_GRASS_WINDROW			= 0;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SEMIDRY_GRASS_WINDROW			= 0;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.SEMIDRY_GRASS_WINDROW			= 60;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.DRYLUZERNE 					= "DRYLUZERNE";-- Lucerne
	RN.cropDensity.DRYLUZERNE 				= 0.180;	-- kg/L
	RN.cropYield.DRYLUZERNE  				= 198.12; 	-- GEO EU 100 kg/ha
	RN.yieldRange.DRYLUZERNE  				= 0.177		-- GEO EU
	RN.seedDensity.DRYLUZERNE  				= 0.737;	-- kg/L
	RN.TSM.DRYLUZERNE  						= 2;		-- 1000 seed mass
	RN.plantsPerSqm.DRYLUZERNE  			= 360;		-- number of plants per sqm
	RN.germination.DRYLUZERNE  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.DRYLUZERNE 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.DRYLUZERNE  		= 46.00;	-- GEO DE, price / 100 kg
	RN.cropPricePer100kg.DRYLUZERNE  		= 16.69;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.DRYLUZERNE  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.DRYLUZERNE					= 40;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.DRYLUZERNE					= 80 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.DRYLUZERNE					= 120;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.DRYLUZERNE				= 60;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.GRASS  						= "GRASS";
	RN.cropDensity.GRASS 					= 0.39;		-- kg/L
	RN.cropYield.GRASS  					= 104.9; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.GRASS  					= 0.153;	-- GEO COM,
	RN.seedDensity.GRASS  					= 0.641;	-- kg/L
	RN.TSM.GRASS  							= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.GRASS  					= 550;		-- number of plants per sqm
	RN.germination.GRASS  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.GRASS 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.GRASS  			= 350.00;	-- GEO UK, price / 100 kg
	RN.cropPricePer100kg.GRASS  			= 5.00;		-- GEO UK, price / 100 kg
	RN.seederCalibration.GRASS  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.GRASS						= 27;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.GRASS						= 9;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.GRASS						= 44;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.GRASS						= 60;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.HEMP  						= "HEMP";
	RN.cropDensity.HEMP 					= 0.564;	-- kg/L
	RN.cropYield.HEMP  						= 19.60; 	-- GEO COM,100 kg/ha
	RN.yieldRange.HEMP  					= 0.200;	-- GEO COM
	RN.seedDensity.HEMP  					= 0.564;	-- kg/L
	RN.TSM.HEMP  							= 16.6;		-- 1000 seed mass
	RN.plantsPerSqm.HEMP  					= 120;		-- number of plants per sqm
	RN.germination.HEMP  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.HEMP 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.HEMP  				= 444.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.HEMP  				= 222.00;	-- GEO COM, price / 100 kg
	RN.seederCalibration.HEMP  				= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.HEMP						= 129;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.HEMP						= 75;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.HEMP						= 64;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.HEMP						= 120;		-- Real-life days from seeding to harvest or between cuts
	
	RN.fruits.HOPS  						= "HOPS";
	RN.cropDensity.HOPS 					= 0.881;	-- kg/L
	RN.cropYield.HOPS  						= 20.16; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.HOPS  					= 0.860;	-- GEO EU,
	RN.seedDensity.HOPS  					= 0.561;	-- kg/L
	RN.TSM.HOPS  							= 40;		-- 1000 seed mass
	RN.plantsPerSqm.HOPS  					= 0.33;		-- number of plants per sqm
	RN.germination.HOPS  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.HOPS 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.HOPS  				= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.HOPS  				= 1037.00;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.HOPS  				= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.HOPS						= 150;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.HOPS						= 20;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.HOPS						= 100;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.HOPS						= 120;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.INCARASE_GRASS  				= "INCARASE_GRASS"; -- Krebach map
	RN.cropDensity.INCARASE_GRASS 			= 0.5;		-- kg/L grass seed
	RN.cropYield.INCARASE_GRASS  			= 144.0; 	-- GEO Krebach,100 kg/ha
	RN.yieldRange.INCARASE_GRASS  			= 0.153;	-- GEO DE
	RN.seedDensity.INCARASE_GRASS  			= 0.641;	-- kg/L
	RN.TSM.INCARASE_GRASS  					= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.INCARASE_GRASS  		= 550;		-- number of plants per sqm
	RN.germination.INCARASE_GRASS  			= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.INCARASE_GRASS 		= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.INCARASE_GRASS  	= 350.00;	-- GEO DE, price / 100 kg
	RN.cropPricePer100kg.INCARASE_GRASS  	= 113.00;	-- GEO Krebach, price / 100 kg
	RN.seederCalibration.INCARASE_GRASS  	= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.INCARASE_GRASS				= 27;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.INCARASE_GRASS				= 9;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.INCARASE_GRASS				= 44;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.INCARASE_GRASS			= 60;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.LETTUCE  						= "LETTUCE";
	RN.cropDensity.LETTUCE 					= 0.368;	-- kg/L
	RN.cropYield.LETTUCE  					= 398.54; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.LETTUCE  					= 0.198;	-- GEO COM,
	RN.seedDensity.LETTUCE  				= 0.368;	-- kg/L
	RN.TSM.LETTUCE  						= 1.3;		-- 1000 seed mass
	RN.plantsPerSqm.LETTUCE  				= 6;		-- number of plants per sqm
	RN.germination.LETTUCE  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.LETTUCE 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.LETTUCE  			= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.LETTUCE  			= 59.75;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.LETTUCE  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.LETTUCE						= 140;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.LETTUCE					= 45 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.LETTUCE					= 230;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.LETTUCE					= 45;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.LUCERNE 						= "LUCERNE";-- Lucerne
	RN.cropDensity.LUCERNE 					= 0.46;		-- kg/L
	RN.cropYield.LUCERNE  					= 198.12; 	-- GEO EU 100 kg/ha
	RN.yieldRange.LUCERNE  					= 0.177		-- GEO EU
	RN.seedDensity.LUCERNE  				= 0.737;	-- kg/L
	RN.TSM.LUCERNE  						= 2;		-- 1000 seed mass
	RN.plantsPerSqm.LUCERNE  				= 360;		-- number of plants per sqm
	RN.germination.LUCERNE  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.LUCERNE 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.LUCERNE  			= 46.00;	-- GEO DE, price / 100 kg
	RN.cropPricePer100kg.LUCERNE  			= 16.69;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.LUCERNE  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.LUCERNE						= 40;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.LUCERNE					= 80 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.LUCERNE					= 120;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.LUCERNE					= 60;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.LUZERNE 						= "LUZERNE";-- Lucerne
	RN.cropDensity.LUZERNE 					= 0.46;		-- kg/L
	RN.cropYield.LUZERNE  					= 198.12; 	-- GEO EU 100 kg/ha
	RN.yieldRange.LUZERNE  					= 0.177		-- GEO EU
	RN.seedDensity.LUZERNE  				= 0.737;	-- kg/L
	RN.TSM.LUZERNE  						= 2;		-- 1000 seed mass
	RN.plantsPerSqm.LUZERNE  				= 360;		-- number of plants per sqm
	RN.germination.LUZERNE  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.LUZERNE 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown :20-37 kg/ha
	RN.seedPricePer100kg.LUZERNE  			= 46.00;	-- GEO DE, price / 100 kg
	RN.cropPricePer100kg.LUZERNE  			= 16.69;	-- GEO DE,  price / 100 kg
	RN.seederCalibration.LUZERNE  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.LUZERNE						= 40;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.LUZERNE					= 80 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.LUZERNE					= 120;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.LUZERNE					= 60;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.MAIZE  						= "MAIZE";
	RN.cropDensity.MAIZE 					= 0.721;	-- kg/L
	RN.cropYield.MAIZE  					= 112.6; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.MAIZE  					= 0.449;	-- GEO COM,
	RN.seedDensity.MAIZE  					= 0.721;	-- kg/L
	RN.TSM.MAIZE  							= 380;		-- 1000 seed mass
	RN.plantsPerSqm.MAIZE  					= 5;		-- number of plants per sqm
	RN.germination.MAIZE  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.MAIZE 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.MAIZE  			= 241.00;	-- GEO US Heartland, price / 100 kg
	RN.cropPricePer100kg.MAIZE  			= 14.41;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.MAIZE  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.MAIZE						= 140;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.MAIZE						= 61;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.MAIZE						= 36;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.MAIZE						= 161;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.MILLET  						= "MILLET";
	RN.cropDensity.MILLET 					= 0.737;	-- kg/L
	RN.cropYield.MILLET  					= 21.55; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.MILLET  					= 0.198;	-- GEO COM,
	RN.seedDensity.MILLET  					= 0.737;	-- kg/L
	RN.TSM.MILLET  							= 10;		-- 1000 seed mass
	RN.plantsPerSqm.MILLET  				= 30;		-- number of plants per sqm
	RN.germination.MILLET  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.MILLET 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.MILLET  			= 20.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.MILLET  			= 13.18;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.MILLET  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.MILLET						= 35;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.MILLET						= 50;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.MILLET						= 25;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.MILLET					= 75;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.MUSTARD  						= "MUSTARD";
	RN.cropDensity.MUSTARD 					= 0.769;	-- kg/L
	RN.cropYield.MUSTARD  					= 8.85; 	-- GEO US Average,100 kg/ha
	RN.yieldRange.MUSTARD  					= 0.198;	-- GEO COM,
	RN.seedDensity.MUSTARD  				= 0.769;	-- kg/L
	RN.TSM.MUSTARD  						= 4.55;		-- 1000 seed mass Yellow mustard
	RN.plantsPerSqm.MUSTARD  				= 143;		-- number of plants per sqm
	RN.germination.MUSTARD  				= 65;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.MUSTARD 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.MUSTARD  			= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.MUSTARD  			= 69.70;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.MUSTARD  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.MUSTARD						= 66;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.MUSTARD					= 20 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.MUSTARD					= 50;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.MUSTARD					= 90;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.OAT  							= "OAT";
	RN.cropDensity.OAT 						= 0.412;	-- kg/L
	RN.cropYield.OAT  						= 23.940; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.OAT  						= 0.212;	-- GEO COM,
	RN.seedDensity.OAT  					= 0.412;	-- kg/L
	RN.TSM.OAT  							= 35;		-- 1000 seed mass
	RN.plantsPerSqm.OAT  					= 250;		-- number of plants per sqm
	RN.germination.OAT  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.OAT 					= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.OAT  				= 62.00;	-- GEO US Heartland, price / 100 kg
	RN.cropPricePer100kg.OAT  				= 21.01;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.OAT  				= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.OAT							= 118;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.OAT						= 45;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.OAT						= 149;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.OAT						= 103;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.OILSEEDRADISH  				= "OILSEEDRADISH";
	RN.cropDensity.OILSEEDRADISH 			= 0.80;		-- kg/L
	RN.cropYield.OILSEEDRADISH  			= 28.50; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.OILSEEDRADISH  			= 0.445;	-- GEO COM,
	RN.seedDensity.OILSEEDRADISH  			= 0.35;		-- kg/L
	RN.TSM.OILSEEDRADISH  					= 15;		-- 1000 seed mass
	RN.plantsPerSqm.OILSEEDRADISH  			= 70;		-- number of plants per sqm
	RN.germination.OILSEEDRADISH  			= 70;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.OILSEEDRADISH 		= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.OILSEEDRADISH  	= 282.00;	-- GEO US Heartland, price / 100 kg
	RN.cropPricePer100kg.OILSEEDRADISH  	= 0;		-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.OILSEEDRADISH  	= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.OILSEEDRADISH				= 0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.OILSEEDRADISH				= 0;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.OILSEEDRADISH				= 0;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.OILSEEDRADISH				= 45;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.ONION  						= "ONION";
	RN.cropDensity.ONION 					= 0.609;	-- kg/L
	RN.cropYield.ONION  					= 481.5; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.ONION  					= 0.198;	-- GEO COM,
	RN.seedDensity.ONION  					= 0.400;	-- kg/L
	RN.TSM.ONION  							= 3.1;		-- 1000 seed mass
	RN.plantsPerSqm.ONION  					= 120;		-- number of plants per sqm, Direct seeding
	RN.germination.ONION  					= 65;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.ONION 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.ONION  			= 30.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.ONION  			= 43.36;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.ONION  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.ONION						= 180;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.ONION						= 100;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.ONION						= 170;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.ONION						= 120;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.PEANUT  						= "PEANUT";
	RN.cropDensity.PEANUT 					= 0.690;	-- kg/L, (shelled)
	RN.cropYield.PEANUT  					= 43.71; 	-- GEO US Heartland,100 kg/ha
	RN.yieldRange.PEANUT  					= 0.198;	-- GEO COM,
	RN.seedDensity.PEANUT	 				= 0.336;	-- kg/L
	RN.TSM.PEANUT	  						= 567;		-- 1000 seed mass
	RN.plantsPerSqm.PEANUT  				= 22;		-- number of plants per sqm
	RN.germination.PEANUT	  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.PEANUT 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.PEANUT  			= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.PEANUT  			= 42.22;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.PEANUT  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.PEANUT						= 33;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.PEANUT						= 25 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.PEANUT						= 20;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.PEANUT					= 155;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.PEAS  						= "PEAS";	-- Green peas
	RN.cropDensity.PEAS 					= 0.561;	-- kg/L (shelled)
	RN.cropYield.PEAS  						= 20.46; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.PEAS  					= 0.412;	-- GEO COM,
	RN.seedDensity.PEAS  					= 0.400;	-- kg/L
	RN.TSM.PEAS  							= 211;		-- 1000 seed mass
	RN.plantsPerSqm.PEAS  					= 85;		-- number of plants per sqm
	RN.germination.PEAS  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.PEAS 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.PEAS  				= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.PEAS  				= 25.91;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.PEAS  				= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.PEAS						= 25;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.PEAS						= 25 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.PEAS						= 20;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.PEAS						= 95;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.POPLAR  						= "POPLAR";
	RN.cropDensity.POPLAR 					= 0.4;		-- kg/L
	RN.cropYield.POPLAR  					= 112.8; 	-- GEO COM, 100 kg/ha, 112.8 is default in-game value
	RN.yieldRange.POPLAR  					= 0;		-- GEO COM
	RN.seedDensity.POPLAR  					= 0.2;		-- kg/L
	RN.TSM.POPLAR  							= 180000;	-- 1000 seed mass
	RN.plantsPerSqm.POPLAR  				= 0.266;	-- number of plants per sqm
	RN.germination.POPLAR  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.POPLAR 				= 0;		-- Only defined if TSM, PlantsPerSqm or Germination are unknown
	RN.seedPricePer100kg.POPLAR  			= 10.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.POPLAR  			= 10.0;		-- GEO COM, price / 100 kg, 10.0 is default in-game value
	RN.seederCalibration.POPLAR  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.POPLAR						= 225;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.POPLAR						= 75 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.POPLAR						= 75;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.POPLAR					= 360;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.POPPY   						= "POPPY";
	RN.cropDensity.POPPY  					= 0.3;		-- kg/L
	RN.cropYield.POPPY   					= 34.80; 	-- GEO COM, 100 kg/ha
	RN.yieldRange.POPPY   					= 0;		-- GEO COM,
	RN.seedDensity.POPPY   					= 0.40;		-- kg/L
	RN.TSM.POPPY   							= 3;		-- 1000 seed mass
	RN.plantsPerSqm.POPPY   				= 70;		-- number of plants per sqm
	RN.germination.POPPY   					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.POPPY  				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.POPPY   			= 200.0;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.POPPY   			= 200.0;	-- GEO COM, price / 100 kg
	RN.seederCalibration.POPPY   			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.POPPY 						= 50;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.POPPY 						= 75 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.POPPY 						= 75;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.POPPY						= 60;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.POTATO  						= "POTATO";
	RN.cropDensity.POTATO 					= 0.75;		-- kg/L
	RN.cropYield.POTATO  					= 383.3; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.POTATO  					= 0.091;	-- GEO COM,
	RN.seedDensity.POTATO  					= 0.75;		-- kg/L
	RN.TSM.POTATO  							= 36000;	-- 1000 seed mass
	RN.plantsPerSqm.POTATO  				= 4;		-- number of plants per sqm
	RN.germination.POTATO  					= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.POTATO 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.POTATO  			= 32.00;	-- GEO US Heartland, price / 100 kg
	RN.cropPricePer100kg.POTATO  			= 23.99;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.POTATO  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.POTATO						= 166;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.POTATO						= 58 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.POTATO						= 250;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.POTATO					= 120;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.REDCABBAGE  					= "REDCABBAGE";
	RN.cropDensity.REDCABBAGE 				= 0.433;	-- kg/L
	RN.cropYield.REDCABBAGE  				= 429.7; 	-- GEO US, 100 kg/ha
	RN.yieldRange.REDCABBAGE  				= 0.198;	-- GEO COM,
	RN.seedDensity.REDCABBAGE  				= 0.433;	-- kg/L
	RN.TSM.REDCABBAGE  						= 3.3;		-- 1000 seed mass
	RN.plantsPerSqm.REDCABBAGE  			= 20;		-- number of plants per sqm
	RN.germination.REDCABBAGE  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.REDCABBAGE 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.REDCABBAGE  		= 36.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.REDCABBAGE  		= 39.77;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.REDCABBAGE  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.REDCABBAGE					= 90;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.REDCABBAGE					= 90;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.REDCABBAGE					= 90;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.REDCABBAGE				= 90;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.RICE  						= "RICE";
	RN.cropDensity.RICE 					= 0.530;	-- kg/L
	RN.cropYield.RICE  						= 80.89; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.RICE  					= 0.345;	-- GEO EU,
	RN.seedDensity.RICE  					= 0.530;	-- kg/L
	RN.TSM.RICE  							= 24;		-- 1000 seed mass
	RN.plantsPerSqm.RICE  					= 170;		-- number of plants per sqm
	RN.germination.RICE  					= 65;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.RICE 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.RICE  				= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.RICE  				= 24.20;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.RICE  				= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.RICE						= 450;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.RICE						= 180;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.RICE						= 100;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.RICE						= 150;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.RYE  							= "RYE";
	RN.cropDensity.RYE 						= 0.721;	-- kg/L
	RN.cropYield.RYE  						= 19.71; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.RYE  						= 0.712;	-- GEO COM,
	RN.seedDensity.RYE  					= 0.721;	-- kg/L
	RN.TSM.RYE  							= 35;		-- 1000 seed mass
	RN.plantsPerSqm.RYE  					= 250;		-- number of plants per sqm
	RN.germination.RYE  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.RYE 					= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.RYE  				= 21.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.RYE  				= 25.04;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.RYE  				= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.RYE							= 30;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.RYE						= 82 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.RYE						= 143;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.RYE						= 280;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.SORGHUM  						= "SORGHUM";
	RN.cropDensity.SORGHUM 					= 0.772;	-- kg/L
	RN.cropYield.SORGHUM  					= 43.53; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.SORGHUM  					= 0.518;	-- GEO EU,
	RN.seedDensity.SORGHUM  				= 0.54;		-- kg/L
	RN.TSM.SORGHUM  						= 32.36;	-- 1000 seed mass
	RN.plantsPerSqm.SORGHUM  				= 12.35;	-- number of plants per sqm
	RN.germination.SORGHUM  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SORGHUM 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SORGHUM  			= 27.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.SORGHUM  			= 13.71;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.SORGHUM  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SORGHUM						= 120;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SORGHUM					= 50 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SORGHUM					= 25;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.SORGHUM					= 140;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.SOYBEAN  						= "SOYBEAN";
	RN.cropDensity.SOYBEAN 					= 0.772;	-- kg/L
	RN.cropYield.SOYBEAN  					= 34.82; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.SOYBEAN  					= 0.554;	-- GEO US Heartland,
	RN.seedDensity.SOYBEAN  				= 0.772;	-- kg/L
	RN.TSM.SOYBEAN  						= 160;		-- 1000 seed mass
	RN.plantsPerSqm.SOYBEAN  				= 30;		-- number of plants per sqm
	RN.germination.SOYBEAN  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SOYBEAN 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SOYBEAN  			= 200.00;	-- GEO US Heartland, price / 100 kg
	RN.cropPricePer100kg.SOYBEAN  			= 35.94;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.SOYBEAN  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SOYBEAN						= 175;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SOYBEAN					= 41;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SOYBEAN					= 50;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.SOYBEAN					= 135;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.SPELT   						= "SPELT";	-- As Wheat
	RN.cropDensity.SPELT  					= 0.735;	-- kg/L
	RN.cropYield.SPELT   					= 78.24; 	-- GEO UK, 100 kg/ha
	RN.yieldRange.SPELT   					= 0.198;	-- GEO COM,
	RN.seedDensity.SPELT   					= 0.772;	-- kg/L
	RN.TSM.SPELT   							= 49;		-- 1000 seed mass
	RN.plantsPerSqm.SPELT   				= 250;		-- number of plants per sqm
	RN.germination.SPELT   					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SPELT  				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SPELT   			= 24.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.SPELT   			= 18.00;	-- GEO UK, price / 100 kg
	RN.seederCalibration.SPELT   			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SPELT 						= 240;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SPELT 						= 82 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SPELT 						= 143;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.SPELT						= 135;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.SUDANGRASS  					= "SUDANGRASS";
	RN.cropDensity.SUDANGRASS 				= 0.39;		-- kg/L
	RN.cropYield.SUDANGRASS  				= 165.8; 	-- GEO COM,100 kg/ha
	RN.yieldRange.SUDANGRASS  				= 0.153;	-- GEO COM
	RN.seedDensity.SUDANGRASS  				= 0.641;	-- kg/L
	RN.TSM.SUDANGRASS  						= 1.4;		-- 1000 seed mass
	RN.plantsPerSqm.SUDANGRASS  			= 550;		-- number of plants per sqm
	RN.germination.SUDANGRASS  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SUDANGRASS 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SUDANGRASS  		= 350.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.SUDANGRASS  		= 5.00;		-- GEO COM, price / 100 kg
	RN.seederCalibration.SUDANGRASS  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SUDANGRASS					= 27;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SUDANGRASS					= 9;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SUDANGRASS					= 44;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.SUDANGRASS				= 60;		-- Real-life days from seeding to harvest or between cuts
	
	RN.fruits.SUGARBEET  					= "SUGARBEET";
	RN.cropDensity.SUGARBEET 				= 0.70;		-- kg/L
	RN.cropYield.SUGARBEET  				= 356.2; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.SUGARBEET  				= 0.070;	-- GEO COM,
	RN.seedDensity.SUGARBEET  				= 0.435;	-- kg/L
	RN.TSM.SUGARBEET  						= 13;		-- 1000 seed mass
	RN.plantsPerSqm.SUGARBEET  				= 18;		-- number of plants per sqm
	RN.germination.SUGARBEET  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SUGARBEET 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SUGARBEET  		= 35.00;	-- GEO US Heartland, price / 100 kg
	RN.cropPricePer100kg.SUGARBEET  		= 2.617;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.SUGARBEET  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SUGARBEET					= 166;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SUGARBEET					= 79;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SUGARBEET					= 294;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.SUGARBEET					= 180;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.SUGARCANE  					= "SUGARCANE";
	RN.cropDensity.SUGARCANE 				= 0.70;		-- kg/L
	RN.cropYield.SUGARCANE  				= 810.2; 	-- GEO US Average,100 kg/ha
	RN.yieldRange.SUGARCANE  				= 0.0;		-- GEO COM,
	RN.seedDensity.SUGARCANE  				= 0.66;		-- kg/L
	RN.TSM.SUGARCANE  						= 250000;	-- 1000 seed mass
	RN.plantsPerSqm.SUGARCANE  				= 4;		-- number of plants per sqm
	RN.germination.SUGARCANE  				= 86;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SUGARCANE 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SUGARCANE  		= 4.60;		-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.SUGARCANE  		= 3.13;		-- GEO US, price / 100 kg
	RN.seederCalibration.SUGARCANE  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SUGARCANE					= 136;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SUGARCANE					= 50;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SUGARCANE					= 100;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.SUGARCANE					= 120;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.SUNFLOWER  					= "SUNFLOWER";
	RN.cropDensity.SUNFLOWER 				= 0.412;	-- kg/L
	RN.cropYield.SUNFLOWER  				= 16.00; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.SUNFLOWER  				= 0.544;	-- GEO COM,
	RN.seedDensity.SUNFLOWER  				= 0.609;	-- kg/L
	RN.TSM.SUNFLOWER  						= 126;		-- 1000 seed mass
	RN.plantsPerSqm.SUNFLOWER  				= 6;		-- number of plants per sqm
	RN.germination.SUNFLOWER  				= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.SUNFLOWER 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.SUNFLOWER  		= 150.00;	-- GEO US Heartland, price / 100 kg
	RN.cropPricePer100kg.SUNFLOWER  		= 44.49;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.SUNFLOWER  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.SUNFLOWER					= 60;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.SUNFLOWER					= 29;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.SUNFLOWER					= 18;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.SUNFLOWER					= 125;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.TOBACCO  						= "TOBACCO";
	RN.cropDensity.TOBACCO 					= 0.772;	-- kg/L
	RN.cropYield.TOBACCO  					= 24.47; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.TOBACCO  					= 0.502;	-- GEO EU,
	RN.seedDensity.TOBACCO  				= 0.772;	-- kg/L
	RN.TSM.TOBACCO  						= 0.09;		-- 1000 seed mass
	RN.plantsPerSqm.TOBACCO  				= 1.85;		-- number of plants per sqm
	RN.germination.TOBACCO  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.TOBACCO 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.TOBACCO  			= 46.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.TOBACCO  			= 596.48;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.TOBACCO  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.TOBACCO						= 90;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.TOBACCO					= 75 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.TOBACCO					= 220;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.TOBACCO					= 100;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.TRITICALE  					= "TRITICALE";
	RN.cropDensity.TRITICALE 				= 0.772;	-- kg/L
	RN.cropYield.TRITICALE  				= 25.11; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.TRITICALE  				= 0.295;	-- GEO UK,
	RN.seedDensity.TRITICALE  				= 0.772;	-- kg/L
	RN.TSM.TRITICALE  						= 36.36;	-- 1000 seed mass
	RN.plantsPerSqm.TRITICALE  				= 190;		-- number of plants per sqm
	RN.germination.TRITICALE  				= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.TRITICALE 			= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.TRITICALE  		= 21.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.TRITICALE  		= 36.55;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.TRITICALE  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.TRITICALE					= 200;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.TRITICALE					= 82 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.TRITICALE					= 143;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.TRITICALE					= 160;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.WEED  						= "WEED";
	RN.cropDensity.WEED 					= 0.46;		-- kg/L
	RN.cropYield.WEED  						= 0; 		-- GEO UK, 100 kg/ha
	RN.yieldRange.WEED  					= 0;		-- GEO COM,
	RN.seedDensity.WEED  					= 0.46;		-- kg/L
	RN.TSM.WEED  							= 0;		-- 1000 seed mass
	RN.plantsPerSqm.WEED  					= 0;		-- number of plants per sqm
	RN.germination.WEED  					= 1;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.WEED 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.WEED  				= 0.00;		-- GEO UK, price / 100 kg
	RN.cropPricePer100kg.WEED  				= 0.00;		-- GEO UK, price / 100 kg
	RN.seederCalibration.WEED  				= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.WEED						= 0;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.WEED						= 0 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.WEED						= 0;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.WEED						= 60;		-- Real-life days from seeding to harvest or between cuts
	RN.minGrowthState.WEED					= 1;
	RN.maxGrowthState.WEED					= 3;	

	RN.fruits.WHEAT  						= "WHEAT";
	RN.cropDensity.WHEAT 					= 0.772;	-- kg/L
	RN.cropYield.WHEAT  					= 45.95; 	-- GEO US Heartland, 100 kg/ha
	RN.yieldRange.WHEAT  					= 0.197;	-- GEO US Heartland,
	RN.seedDensity.WHEAT  					= 0.772;	-- kg/L
	RN.TSM.WHEAT  							= 40;		-- 1000 seed mass
	RN.plantsPerSqm.WHEAT  					= 250;		-- number of plants per sqm
	RN.germination.WHEAT  					= 90;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.WHEAT 				= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.WHEAT  			= 52.00;	-- GEO US Heartland, price / 100 kg
	RN.cropPricePer100kg.WHEAT  			= 16.87;	-- GEO US Heartland, price / 100 kg
	RN.seederCalibration.WHEAT  			= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.WHEAT						= 240;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.WHEAT						= 82 ;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.WHEAT						= 143;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.WHEAT						= 255;		-- Real-life days from seeding to harvest or between cuts

	RN.fruits.WHITECABBAGE  				= "WHITECABBAGE";
	RN.cropDensity.WHITECABBAGE 			= 0.433;	-- kg/L
	RN.cropYield.WHITECABBAGE  				= 429.7; 	-- GEO US Average, 100 kg/ha
	RN.yieldRange.WHITECABBAGE  			= 0.198;	-- GEO COM,
	RN.seedDensity.WHITECABBAGE  			= 0.433;	-- kg/L
	RN.TSM.WHITECABBAGE  					= 3.3;		-- 1000 seed mass
	RN.plantsPerSqm.WHITECABBAGE  			= 20;		-- number of plants per sqm
	RN.germination.WHITECABBAGE  			= 80;		-- Percentage of seeds that germinate
	RN.seedUsagePerSqm.WHITECABBAGE 		= 0;		-- kg/sqm, Only defined if TSM, PlantsPerSqm and Germination are unknown
	RN.seedPricePer100kg.WHITECABBAGE  		= 57.00;	-- GEO COM, price / 100 kg
	RN.cropPricePer100kg.WHITECABBAGE  		= 39.77;	-- GEO US Average, price / 100 kg
	RN.seederCalibration.WHITECABBAGE  		= 1.000;	-- If seeder calibration is wanted.
	RN.Nitrogen.WHITECABBAGE				= 90;		-- kg/ha Nitrogen  (N) fertilizer per year
	RN.Phosphate.WHITECABBAGE				= 90;		-- kg/ha Phosphate (P) fertilizer per year
	RN.Potassium.WHITECABBAGE				= 90;		-- kg/ha Potassium (K) fertilizer per year
	RN.growthDays.WHITECABBAGE				= 90;		-- Real-life days from seeding to harvest or between cuts


	RN.commodityPriceVariation = 10; 	-- price fluctuation in percentage
	RN.commodityName = {};
	RN.commodityDensity = {};
	RN.commodityVolume = {};
	RN.commodityPricePer100kg = {};

	RN.numberRoundBalesPerHa = {};
	RN.numberSquareBalesPerHa = {};

	RN.squareBale = {};
	RN.squareBale.length  							= 2.4; -- m
	RN.squareBale.width  							= 1.2; -- m
	RN.squareBale.height  							= 0.9; -- m
	RN.squareBale.volume							= 1000 * RN.squareBale.length * RN.squareBale.width * RN.squareBale.height;
	RN.squareBale.volume							= 10 * round(RN.squareBale.volume/10);

	RN.roundBale = {};
	RN.roundBale.diameter  							= 1.3; -- m
	RN.roundBale.width  							= 1.12; -- m	
	RN.roundBale.volume								= 1000 * 3.14159 * RN.roundBale.width * RN.roundBale.diameter * RN.roundBale.diameter / 4;
	RN.roundBale.volume								= 10 * round(RN.roundBale.volume/10);

	RN.commodityName.APFEL 							= "APFEL";
	RN.commodityDensity.APFEL 						= 0.300;	-- kg/L
	RN.commodityPricePer100kg.APFEL 				= 50.60;	-- GEO DE, €-£-$/100 kg

	RN.commodityName.ASPARAGUS 						= "ASPARAGUS";
	RN.commodityDensity.ASPARAGUS 					= 0.325;	-- kg/L
	RN.commodityPricePer100kg.ASPARAGUS 			= 443.08;	-- GEO Sudhemmern, €-£-$/100 kg

	RN.commodityName.BEER 							= "BEER";
	RN.commodityDensity.BEER 						= 0.900;	-- kg/L
	RN.commodityPricePer100kg.BEER 					= 122.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.BEETPULP  						= "BEETPULP";
	RN.commodityDensity.BEETPULP  					= 0.415;	-- kg/L
	RN.commodityPricePer100kg.BEETPULP  			= 5.00;	 	-- GEO COM, €-£-$/100 kg

	RN.commodityName.BIOMASS 						= "BIOMASS";
	RN.commodityDensity.BIOMASS 					= 0.415;	-- kg/L
	RN.commodityPricePer100kg.BIOMASS 				= 7.95;		-- GEO COM, €-£-$/100 kg

	RN.commodityName.BIRNE 							= "BIRNE";
	RN.commodityDensity.BIRNE 						= 0.300;	-- kg/L
	RN.commodityPricePer100kg.BIRNE 				= 57.20;	-- GEO DE, €-£-$/100 kg

	RN.commodityName.BOOZE 							= "BOOZE";
	RN.commodityDensity.BOOZE 						= 0.450;	-- kg/L
	RN.commodityPricePer100kg.BOOZE 				= 311.11;	-- GEO Sudhemmern, €-£-$/100 kg

	RN.commodityName.BUTTER 						= "BUTTER";
	RN.commodityDensity.BUTTER 						= 0.500;	-- kg/L
	RN.commodityPricePer100kg.BUTTER 				= 346.00;	-- GEO US Average, €-£-$/100 kg

	RN.commodityName.CEREAL_BREAD 					= "CEREAL_BREAD";
	RN.commodityDensity.CEREAL_BREAD 				= 0.68;		-- kg/L 
	RN.commodityPricePer100kg.CEREAL_BREAD 			= 47.80;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.CHAFF 							= "CHAFF";
	RN.commodityDensity.CHAFF 						= 0.175;	-- kg/L
	RN.commodityPricePer100kg.CHAFF 				= 24.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.CHEESE 						= "CHEESE";
	RN.commodityDensity.CHEESE 						= 0.500;	-- kg/L
	RN.commodityPricePer100kg.CHEESE 				= 356.00;	-- GEO US Average, €-£-$/100 kg

	RN.commodityName.CHERRY 						= "CHERRY";
	RN.commodityDensity.CHERRY 						= 0.325;	-- kg/L
	RN.commodityPricePer100kg.CHERRY 				= 285.20;	-- GEO DE, €-£-$/100 kg

	RN.commodityName.CHICKENFOOD 					= "CHICKENFOOD";
	RN.commodityDensity.CHICKENFOOD 				= 0.70;		-- kg/L less than 0.7 kg/L at 3 - 6 months
	RN.commodityPricePer100kg.CHICKENFOOD 			= 25.00;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.COAL 							= "COAL";
	RN.commodityDensity.COAL 						= 0.5;		-- kg/L
	RN.commodityPricePer100kg.COAL 					= 62.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.COMPOST 						= "COMPOST";
	RN.commodityDensity.COMPOST 					= 0.6;		-- kg/L less than 0.7 kg/L at 3 - 6 months
	RN.commodityPricePer100kg.COMPOST 				= 4.94;		-- GEO COM, €-£-$/100 kg

	RN.commodityName.COWFOOD 						= "COWFOOD";
	RN.commodityDensity.COWFOOD 					= 0.187;	-- kg/L 50% hay, 25% straw, 25% silage
	RN.commodityPricePer100kg.COWFOOD 				= 24.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.DEF 							= "DEF";
	RN.commodityDensity.DEF 						= 0.5;		-- kg/L
	RN.commodityPricePer100kg.DEF 					= 250.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.DIESEL 						= "DIESEL";
	RN.commodityDensity.DIESEL 						= 0.84;		-- kg/L
	RN.commodityPricePer100kg.DIESEL 				= 106.42;	-- GEO US Heartland, €-£-$/100 kg

	RN.commodityName.DIGESTATE 						= "DIGESTATE";
	RN.commodityDensity.DIGESTATE 					= 0.90;		-- kg/L
	RN.commodityPricePer100kg.DIGESTATE 			= 0.360;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.DRYLUZERNE 					= "DRYLUZERNE";
	RN.commodityDensity.DRYLUZERNE 					= 0.035;	-- kg/L
	RN.commodityPricePer100kg.DRYLUZERNE 			= 137.14;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.DRYLUZERNE_WINDROW 			= "DRYLUZERNE_WINDROW";
	RN.commodityDensity.DRYLUZERNE_WINDROW 			= 0.035;	-- kg/L
	RN.commodityPricePer100kg.DRYLUZERNE_WINDROW 	= 160.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.EGG 							= "EGG";
	RN.commodityDensity.EGG 						= 0.257;	-- kg/L
	RN.commodityPricePer100kg.EGG 					= 157.43;	-- GEO US Heartland price, €-£-$/100 kg

	RN.commodityName.ERDE 							= "ERDE";
	RN.commodityDensity.ERDE 						= 0.39;		-- kg/L
	RN.commodityPricePer100kg.ERDE 					= 51.28;	-- GEO Map price, €-£-$/100 kg

	RN.commodityName.FERTILIZER 					= "FERTILIZER";
	RN.commodityDensity.FERTILIZER 					= 0.80;		-- kg/L
	RN.commodityPricePer100kg.FERTILIZER 			= 62.53;	-- GEO US Heartland, €-£-$/100 kg

	RN.commodityName.FLOUR 							= "FLOUR";
	RN.commodityDensity.FLOUR 						= 0.39;		-- kg/L Kandelin map
	RN.commodityPricePer100kg.FLOUR 				= 214.00;	-- GEO Map price, €-£-$/100 kg

	RN.commodityName.FORAGE		 					= "FORAGE";	-- cow feed
	RN.commodityDensity.FORAGE 						= 0.15;		-- kg/L
	RN.commodityPricePer100kg.FORAGE 				= 28.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.FORAGE_MIXING 					= "FORAGE_MIXING";
	RN.commodityDensity.FORAGE_MIXING 				= 0.22;		-- kg/L
	RN.commodityPricePer100kg.FORAGE_MIXING 		= 47.27;	-- GEO US Heartland, €-£-$/100 kg

	RN.commodityName.FUEL 							= "FUEL";
	RN.commodityDensity.FUEL 						= 0.75;		-- kg/L
	RN.commodityPricePer100kg.FUEL 					= 102.85;	-- GEO US Heartland, €-£-$/100 kg

	RN.commodityName.GRAVEL 						= "GRAVEL";
	RN.commodityDensity.GRAVEL 						= 0.50;		-- kg/L
	RN.commodityPricePer100kg.GRAVEL 				= 66.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.GROATS 						= "GROATS"; -- Pigfood
	RN.commodityDensity.GROATS 						= 0.65;		-- kg/L Kandelin map
	RN.commodityPricePer100kg.GROATS 				= 29.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.HERBICIDE 						= "HERBICIDE";
	RN.commodityDensity.HERBICIDE 					= 1.00;		-- kg/L
	RN.commodityPricePer100kg.HERBICIDE 			= 1026.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.HMILK 							= "HMILK";
	RN.commodityDensity.HMILK 						= 1.00;		-- kg/L
	RN.commodityPricePer100kg.HMILK 				= 50.00;	-- GEO Sudhemmern, €-£-$/100 kg

	RN.commodityName.HORSEFOOD 						= "HORSEFOOD";
	RN.commodityDensity.HORSEFOOD 					= 0.05;		-- kg/L less than 0.7 kg/L at 3 - 6 months
	RN.commodityPricePer100kg.HORSEFOOD 			= 166.00;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.KIES 							= "KIES";
	RN.commodityDensity.KIES 						= 0.39;		-- kg/L
	RN.commodityPricePer100kg.KIES 					= 51.28;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.KIRSCHE 						= "KIRSCHE";
	RN.commodityDensity.KIRSCHE 					= 0.300;	-- kg/L
	RN.commodityPricePer100kg.KIRSCHE 				=  285.20;	-- GEO DE, €-£-$/100 kg

	RN.commodityName.LIME 							= "LIME";
	RN.commodityDensity.LIME 						= 1.20;		-- kg/L
	RN.commodityPricePer100kg.LIME 					= 5.36;		-- GEO COM, €-£-$/100 kg

	RN.commodityName.LIQUIDFERTILIZER 				= "LIQUIDFERTILIZER";
	RN.commodityDensity.LIQUIDFERTILIZER 			= 1.30;		-- kg/L
	RN.commodityPricePer100kg.LIQUIDFERTILIZER 		= 62.53;	-- GEO US Heartland, €-£-$/100 kg

	RN.commodityName.LIQUIDMANURE 					= "LIQUIDMANURE";
	RN.commodityDensity.LIQUIDMANURE 				= 0.90;		-- kg/L
	RN.commodityPricePer100kg.LIQUIDMANURE 			= 0.73;		-- GEO COM, €-£-$/100 kg

	RN.commodityName.LUZERNE_WINDROW 				= "LUZERNE_WINDROW";
	RN.commodityDensity.LUZERNE_WINDROW 			= 0.175;	-- kg/L
	RN.commodityPricePer100kg.LUZERNE_WINDROW 		= 25.71;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.MALT 							= "MALT";
	RN.commodityDensity.MALT 						= 0.78;		-- kg/L Suedhemmern 3.5
	RN.commodityPricePer100kg.MALT 					= 68.60;	-- GEO Suedhemmern 3.5, €-£-$/100 kg

	RN.commodityName.MANURE 						= "MANURE";
	RN.commodityDensity.MANURE 						= 0.60;		-- kg/L
	RN.commodityPricePer100kg.MANURE 				= 0.80;		-- GEO COM, €-£-$/100 kg

	RN.commodityName.MEAT 							= "MEAT";
	RN.commodityDensity.MEAT 						= 1.00;		-- kg/L Kandelin map
	RN.commodityPricePer100kg.MEAT 					= 75.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.MEHL 							= "MEHL";
	RN.commodityDensity.MEHL 						= 0.39;		-- kg/L Kandelin map
	RN.commodityPricePer100kg.MEHL 					= 220.00;	-- GEO Map price, €-£-$/100 kg

	RN.commodityName.MILK 							= "MILK";
	RN.commodityDensity.MILK 						= 1.025;	-- kg/L
	RN.commodityPricePer100kg.MILK 					= 43.78;	-- GEO US Heartland, €-£-$/100 kg

	RN.commodityName.OAT 							= "OAT";
	RN.commodityDensity.OAT 						= RN.cropDensity.OAT;	-- kg/L
	RN.commodityPricePer100kg.OAT 					= 1.3 * RN.cropPricePer100kg.OAT;	-- €-£-$/100 kg

	RN.commodityName.ORE 							= "ORE";
	RN.commodityDensity.ORE 						= 0.50;		-- kg/L
	RN.commodityPricePer100kg.ORE 					= 64.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.PEAT 							= "PEAT";
	RN.commodityDensity.PEAT 						= 0.390;	-- kg/L
	RN.commodityPricePer100kg.PEAT 					= 214.00;	-- GEO Map price, €-£-$/100 kg

	RN.commodityName.PELLETS 						= "PELLETS";
	RN.commodityDensity.PELLETS 					= 0.375;	-- kg/L
	RN.commodityPricePer100kg.PELLETS 				= 101.00;	-- GEO Map price, €-£-$/100 kg

	RN.commodityName.PFLAUME 						= "PFLAUME";
	RN.commodityDensity.PFLAUME 					= 0.325;	-- kg/L
	RN.commodityPricePer100kg.PFLAUME 				= 73.30;	-- GEO DE, €-£-$/100 kg

	RN.commodityName.PIGFOOD 						= "PIGFOOD";
	RN.commodityDensity.PIGFOOD 					= 0.679;	-- kg/L
	RN.commodityPricePer100kg.PIGFOOD 				= 55.92;	-- GEO US Heartland, €-£-$/100 kg

	RN.commodityName.PLUM 							= "PLUM";
	RN.commodityDensity.PLUM 						= 0.325;	-- kg/L
	RN.commodityPricePer100kg.PLUM 					= 73.30;	-- GEO DE, €-£-$/100 kg

	RN.commodityName.RUM 							= "RUM";
	RN.commodityDensity.RUM 						= 0.450;	-- kg/L
	RN.commodityPricePer100kg.RUM 					= 311.11;	-- GEO Sudhemmern, €-£-$/100 kg

	RN.commodityName.RYE_WINDROW 					= "RYE_WINDROW";
	RN.commodityDensity.RYE_WINDROW 				= 0.030;	-- kg/L
	RN.commodityPricePer100kg.RYE_WINDROW 			= 136.66;	-- GEO FS19_RDC , €-£-$/100 kg

	RN.commodityName.SAND 							= "SAND";
	RN.commodityDensity.SAND 						= 0.50;		-- kg/L
	RN.commodityPricePer100kg.SAND 					= 64.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.SALT 							= "SALT";
	RN.commodityDensity.SALT 						= 0.50;		-- kg/L
	RN.commodityPricePer100kg.SALT 					= 64.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.SEEDS 							= "SEEDS";
	RN.commodityDensity.SEEDS 						= 0.32;		-- kg/L
	RN.commodityPricePer100kg.SEEDS 				= 113.05;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.SHEEPFOOD 						= "SHEEPFOOD";
	RN.commodityDensity.SHEEPFOOD 					= 0.05;		-- kg/L less than 0.7 kg/L at 3 - 6 months
	RN.commodityPricePer100kg.SHEEPFOOD 			= 82.00;	-- GEO FS19_RDC, €-£-$/100 kg

	RN.commodityName.SILAGE 						= "SILAGE";
	RN.commodityDensity.SILAGE 						= 0.225;	-- kg/L
	RN.commodityPricePer100kg.SILAGE 				= 76.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.SILT 							= "SILT";
	RN.commodityDensity.SILT 						= 0.50;		-- kg/L
	RN.commodityPricePer100kg.SILT 					= 64.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.STONE 							= "STONE";
	RN.commodityDensity.STONE 						= 0.50;		-- kg/L
	RN.commodityPricePer100kg.STONE 				= 64.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.SUGAR 							= "SUGAR";
	RN.commodityDensity.SUGAR 						= 0.390;		-- kg/L
	RN.commodityPricePer100kg.SUGAR 				= 239.75;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.YOGURT 						= "YOGURT";
	RN.commodityDensity.YOGURT 						= 0.450;	-- kg/L
	RN.commodityPricePer100kg.YOGURT 				= 533.33;	-- GEO Sudhemmern, €-£-$/100 kg

	RN.commodityName.WASHEDPOTATO 					= "WASHEDPOTATO";
	RN.commodityDensity.WASHEDPOTATO 				= 0.75;		-- kg/L
	RN.commodityPricePer100kg.WASHEDPOTATO 			= 28.80;	-- GEO +20% ompared to potato, €-£-$/100 kg

	RN.commodityName.WATER 							= "WATER";
	RN.commodityDensity.WATER 						= 1.00;		-- kg/L
	RN.commodityPricePer100kg.WATER 				= 10.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.WHEAT 							= "WHEAT";	-- chicken feed
	RN.commodityDensity.WHEAT 						= RN.cropDensity.WHEAT;	-- kg/L
	RN.commodityPricePer100kg.WHEAT 				= 1.3 * RN.cropPricePer100kg.WHEAT;	-- €-£-$/100 kg

	RN.commodityName.WHOLEGRAIN 					= "WHOLEGRAIN";	
	RN.commodityDensity.WHOLEGRAIN 					= 0.300;	-- kg/L
	RN.commodityPricePer100kg.WHOLEGRAIN 			= 104.33;	-- €-£-$/100 kg

	RN.commodityName.WOODCHIPS 						= "WOODCHIPS";
	RN.commodityDensity.WOODCHIPS 					= 0.175;	-- kg/L
	RN.commodityPricePer100kg.WOODCHIPS 			= 45.71;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.WOOL 						    = "WOOL";
	RN.commodityDensity.WOOL 						= 0.375;	-- kg/L in wool bale
	RN.commodityPricePer100kg.WOOL 					= 152.78;	-- GEO US Heartland, €-£-$/100 kg
	
	RN.commodityName.ZUCKER 						= "ZUCKER";
	RN.commodityDensity.ZUCKER 						= 0.425;	-- kg/L
	RN.commodityPricePer100kg.ZUCKER 				= 176.47;	-- GEO Map price, €-£-$/100 kg

	RN.commodityName.ROUNDBALE 						= "ROUNDBALE";
	RN.commodityDensity.ROUNDBALE 					= 0.39;		-- kg/L
	RN.commodityVolume.ROUNDBALE					= RN.roundBale.volume;		-- L
	RN.commodityPricePer100kg.ROUNDBALE 			= 12.00;	-- GEO COM, €-£-$/100 kg

	RN.commodityName.ROUNDBALE_ALFALFA  			= "ROUNDBALE_ALFALFA ";
	RN.commodityDensity.ROUNDBALE_ALFALFA  			= 0.39;		-- kg/L
	RN.commodityVolume.ROUNDBALE_ALFALFA 			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_ALFALFA  	= 7.80;		-- GEO COM, €-£-$/100 kg		

	RN.commodityName.ROUNDBALE_DRYALFALFA 			= "ROUNDBALE_DRYALFALFA";
	RN.commodityDensity.ROUNDBALE_DRYALFALFA 		= 0.18;		-- kg/L
	RN.commodityVolume.ROUNDBALE_DRYALFALFA			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_DRYALFALFA 	= 7.80;		-- GEO COM, €-£-$/100 kg		
	
	RN.commodityName.ROUNDBALE_CLOVER 				= "ROUNDBALE_CLOVER";
	RN.commodityDensity.ROUNDBALE_CLOVER 			= 0.39;		-- kg/L
	RN.commodityVolume.ROUNDBALE_CLOVER				= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_CLOVER 		= 5.00;		-- GEO COM, €-£-$/100 kg

	RN.commodityName.ROUNDBALE_DRYCLOVER 			= "ROUNDBALE_DRYCLOVER";
	RN.commodityDensity.ROUNDBALE_DRYCLOVER 		= 0.18;		-- kg/L
	RN.commodityVolume.ROUNDBALE_DRYCLOVER			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_DRYCLOVER 	= 7.80;		-- GEO COM, €-£-$/100 kg		
	
	RN.commodityName.ROUNDBALE_GRASS 				= "ROUNDBALE_GRASS";
	RN.commodityDensity.ROUNDBALE_GRASS 			= 0.39;		-- kg/L
	RN.commodityVolume.ROUNDBALE_GRASS				= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_GRASS 		= 5.00;		-- GEO COM, €-£-$/100 kg	
	
	RN.commodityName.ROUNDBALE_DRYGRASS 			= "ROUNDBALE_DRYGRASS";
	RN.commodityDensity.ROUNDBALE_DRYGRASS 			= 0.18;		-- kg/L
	RN.commodityVolume.ROUNDBALE_DRYGRASS			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_DRYGRASS 	= 12.00;	-- GEO COM, €-£-$/100 kg	

	RN.commodityName.ROUNDBALE_LUZERNE 				= "ROUNDBALE_LUZERNE";
	RN.commodityDensity.ROUNDBALE_LUZERNE 			= 0.39;		-- kg/L
	RN.commodityVolume.ROUNDBALE_LUZERNE			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_LUZERNE 	= 7.80;		-- GEO COM, €-£-$/100 kg		

	RN.commodityName.ROUNDBALE_DRYLUZERNE 			= "ROUNDBALE_DRYLUZERNE";
	RN.commodityDensity.ROUNDBALE_DRYLUZERNE 		= 0.18;		-- kg/L
	RN.commodityVolume.ROUNDBALE_DRYLUZERNE			= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_DRYLUZERNE 	= 7.80;		-- GEO COM, €-£-$/100 kg		
	
	RN.commodityName.ROUNDBALE_RYE 					= "ROUNDBALE_RYE";
	RN.commodityDensity.ROUNDBALE_RYE 				= 0.13;		-- kg/L
	RN.commodityVolume.ROUNDBALE_RYE				= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_RYE 		= 7.80;		-- GEO COM, €-£-$/100 kg		

	RN.commodityName.ROUNDBALE_WHEAT 				= "ROUNDBALE_WHEAT";
	RN.commodityDensity.ROUNDBALE_WHEAT 			= 0.13;		-- kg/L
	RN.commodityVolume.ROUNDBALE_WHEAT				= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_WHEAT 		= 7.80;		-- GEO COM, €-£-$/100 kg		
	
	RN.commodityName.ROUNDBALE_BARLEY 				= "ROUNDBALE_BARLEY";
	RN.commodityDensity.ROUNDBALE_BARLEY 			= 0.13;		-- kg/L
	RN.commodityVolume.ROUNDBALE_BARLEY				= RN.roundBale.volume;		-- L width="1.12" diameter="1.3"
	RN.commodityPricePer100kg.ROUNDBALE_BARLEY 		= 7.80;		-- GEO COM, €-£-$/100 kg		
	
	RN.commodityName.SQUAREBALE 					= "SQUAREBALE";
	RN.commodityDensity.SQUAREBALE 					= 0.18;		-- kg/L
	RN.commodityVolume.SQUAREBALE					= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE 			= 12.00;	-- GEO COM, €-£-$/100 kg	

	RN.commodityName.SQUAREBALE_ALFALFA 			= "SQUAREBALE_ALFALFA";
	RN.commodityDensity.SQUAREBALE_ALFALFA 			= 0.39;		-- kg/L
	RN.commodityVolume.SQUAREBALE_ALFALFA			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_ALFALFA 	= 7.80;		-- GEO COM, €-£-$/100 kg	

	RN.commodityName.SQUAREBALE_DRYALFALFA 			= "SQUAREBALE_DRYALFALFA";
	RN.commodityDensity.SQUAREBALE_DRYALFALFA 		= 0.18;		-- kg/L
	RN.commodityVolume.SQUAREBALE_DRYALFALFA		= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_DRYALFALFA = 7.80;		-- GEO COM, €-£-$/100 kg	
	
	RN.commodityName.SQUAREBALE_BARLEY 				= "SQUAREBALE_BARLEY";
	RN.commodityDensity.SQUAREBALE_BARLEY 			= 0.13;		-- kg/L
	RN.commodityVolume.SQUAREBALE_BARLEY			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_BARLEY 	= 7.80;		-- GEO COM, €-£-$/100 kg	

	RN.commodityName.SQUAREBALE_CLOVER 				= "SQUAREBALE_CLOVER";
	RN.commodityDensity.SQUAREBALE_CLOVER 			= 0.39;		-- kg/L
	RN.commodityVolume.SQUAREBALE_CLOVER			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_CLOVER 	= 7.80;		-- GEO COM, €-£-$/100 kg	

	RN.commodityName.SQUAREBALE_DRYCLOVER 			= "SQUAREBALE_DRYCLOVER";
	RN.commodityDensity.SQUAREBALE_DRYCLOVER 		= 0.18;		-- kg/L
	RN.commodityVolume.SQUAREBALE_DRYCLOVER			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_DRYCLOVER 	= 7.80;		-- GEO COM, €-£-$/100 kg	

	RN.commodityName.SQUAREBALE_LUZERNE 			= "SQUAREBALE_LUZERNE";
	RN.commodityDensity.SQUAREBALE_LUZERNE 			= 0.39;		-- kg/L
	RN.commodityVolume.SQUAREBALE_LUZERNE			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_LUZERNE 	= 7.80;		-- GEO COM, €-£-$/100 kg	

	RN.commodityName.SQUAREBALE_DRYLUZERNE 			= "SQUAREBALE_DRYLUZERNE";
	RN.commodityDensity.SQUAREBALE_DRYLUZERNE 		= 0.18;		-- kg/L
	RN.commodityVolume.SQUAREBALE_DRYLUZERNE		= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_DRYLUZERNE = 7.80;		-- GEO COM, €-£-$/100 kg	

	RN.commodityName.SQUAREBALE_RYE 				= "SQUAREBALE_RYE";
	RN.commodityDensity.SQUAREBALE_RYE 				= 0.13;		-- kg/L
	RN.commodityVolume.SQUAREBALE_RYE				= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_RYE 		= 7.80;		-- GEO COM, €-£-$/100 kg	

	RN.commodityName.SQUAREBALE_SILAGE 				= "SQUAREBALE_SILAGE";
	RN.commodityDensity.SQUAREBALE_SILAGE 			= 0.39;		-- kg/L
	RN.commodityVolume.SQUAREBALE_SILAGE			= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_SILAGE 	= 12.0;		-- GEO COM, €-£-$/100 kg	

	RN.commodityName.SQUAREBALE_WHEAT 				= "SQUAREBALE_WHEAT";
	RN.commodityDensity.SQUAREBALE_WHEAT 			= 0.13;		-- kg/L
	RN.commodityVolume.SQUAREBALE_WHEAT				= RN.squareBale.volume;		-- L width="1.20" height="0.90" length="2.40"
	RN.commodityPricePer100kg.SQUAREBALE_WHEAT 		= 7.80;		-- GEO COM, €-£-$/100 kg		


	print("\n============================"..modName.." by ArmChairFarming ============================\n");
	print("\nFS19_RealLifeNumbers: RealNumbersInitialization active")

	if RN.multiPlayer then
		print("\n------------------------Multi-player mode-------------------------\n");
		print("\n-------------This mod is not 100% multiplayer enabled---------------\n");
	else
		print("\n------------------------Single-player mode-------------------------\n");
	end;
	
	
	RN.playTime = nil;
	RN.randomness = 0;
	RNS.daysPerSeason = 3;			-- Default value for playing without Season
	RN.gameDaysPerYear 	= 4 * RNS.daysPerSeason;
	
	local savegameDirectory = g_currentMission.missionInfo.savegameDirectory;	-- works except when a new map is opened the first time
	if savegameDirectory ~= nil then
		local careerFile = savegameDirectory.."/careerSavegame.xml";
		if isDebug2 then print("careerFile : "..tostring(careerFile)); end;
		local xmlFile = loadXMLFile("careerFile", careerFile);		
		local key = string.format("careerSavegame.statistics");
		if not hasXMLProperty(xmlFile, "careerSavegame") then
			if isDebug2 then print("Does not have XMLproperty"); end;
		end;
		RN.playTime = 1000 * getXMLFloat(xmlFile, "careerSavegame.statistics.playTime");

		local seasonsFile = savegameDirectory.."/seasons.xml";
		if isDebug2 then print("seasonsFile : "..tostring(seasonsFile)); end;
		local xmlSeasons  = loadXMLFile("seasonsFile", seasonsFile);
		if not hasXMLProperty(xmlSeasons, "seasonsFile") then				
			if isDebug2 then print("seasonsFile does not have XMLproperty"); end;
		end
		RNS.daysPerSeason = getXMLInt(xmlSeasons, "seasons.environment.daysPerSeason");
		RN.gameDaysPerYear 	= 4 * RNS.daysPerSeason;	-- Set in Seasons in-game menu			
	end;
	RN.gameDaysofYearLeftPrevious = RN.gameDaysPerYear;
	

	if RN.playTime == nil then
		if isDebug2 then print("playTime is nil") end;
		RN.randomness = 0;
	else
		local randomSeednumber = math.randomseed(RN.playTime);
		if isDebug2 then print("playTime is "..RN.playTime/1000); end;
		if isDebug2 then print("random number is "..math.random()); end;
		RN.randomness = 1.
	end;



end;


function RealNumbersInitialization:keyEvent(unicode, sym, modifier, isDown)
end;
function RealNumbersInitialization:update(dt)
end;
function RealNumbersInitialization:draw()
end;
function RealNumbersInitialization:deleteMap()
end;
function RealNumbersInitialization:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersInitialization);
